@@ -1,4 +1,4 @@
-// C++/WinRT v2.0.240405.15
+// C++/WinRT v2.0.250303.1
 
 // SPDX-License-Identifier: MIT OR Apache-2.0
 // SPDX-FileCopyrightText: Copyright (c) Microsoft Corporation
@@ -10,8 +10,8 @@
 #ifndef WINRT_Windows_Security_Authentication_Web_H
 #define WINRT_Windows_Security_Authentication_Web_H
 #include "winrt/base.h"
-static_assert(winrt::check_version(CPPWINRT_VERSION, "2.0.240405.15"), "Mismatched C++/WinRT headers.");
-#define CPPWINRT_VERSION "2.0.240405.15"
+static_assert(winrt::check_version(CPPWINRT_VERSION, "2.0.250303.1"), "Mismatched C++/WinRT headers.");
+#define CPPWINRT_VERSION "2.0.250303.1"
 #include "winrt/impl/Windows.Foundation.2.h"
 #include "winrt/impl/Windows.Foundation.Collections.2.h"
 #include "winrt/impl/Windows.Security.Authentication.Web.2.h"
@@ -20,61 +20,193 @@ namespace winrt::impl
     template <typename D> auto consume_Windows_Security_Authentication_Web_IWebAuthenticationBrokerStatics<D>::AuthenticateAsync(winrt::Windows::Security::Authentication::Web::WebAuthenticationOptions const& options, winrt::Windows::Foundation::Uri const& requestUri, winrt::Windows::Foundation::Uri const& callbackUri) const
     {
         void* asyncInfo{};
-        check_hresult(WINRT_IMPL_SHIM(winrt::Windows::Security::Authentication::Web::IWebAuthenticationBrokerStatics)->AuthenticateWithCallbackUriAsync(static_cast<uint32_t>(options), *(void**)(&requestUri), *(void**)(&callbackUri), &asyncInfo));
+        if constexpr (!std::is_same_v<D, winrt::Windows::Security::Authentication::Web::IWebAuthenticationBrokerStatics>)
+        {
+            winrt::hresult _winrt_cast_result_code;
+            auto const _winrt_casted_result = impl::try_as_with_reason<winrt::Windows::Security::Authentication::Web::IWebAuthenticationBrokerStatics, D const*>(static_cast<D const*>(this), _winrt_cast_result_code);
+            check_hresult(_winrt_cast_result_code);
+            auto const _winrt_abi_type = *(abi_t<winrt::Windows::Security::Authentication::Web::IWebAuthenticationBrokerStatics>**)&_winrt_casted_result;
+            check_hresult(_winrt_abi_type->AuthenticateWithCallbackUriAsync(static_cast<uint32_t>(options), *(void**)(&requestUri), *(void**)(&callbackUri), &asyncInfo));
+        }
+        else
+        {
+            auto const _winrt_abi_type = *(abi_t<winrt::Windows::Security::Authentication::Web::IWebAuthenticationBrokerStatics>**)this;
+            check_hresult(_winrt_abi_type->AuthenticateWithCallbackUriAsync(static_cast<uint32_t>(options), *(void**)(&requestUri), *(void**)(&callbackUri), &asyncInfo));
+        }
         return winrt::Windows::Foundation::IAsyncOperation<winrt::Windows::Security::Authentication::Web::WebAuthenticationResult>{ asyncInfo, take_ownership_from_abi };
     }
     template <typename D> auto consume_Windows_Security_Authentication_Web_IWebAuthenticationBrokerStatics<D>::AuthenticateAsync(winrt::Windows::Security::Authentication::Web::WebAuthenticationOptions const& options, winrt::Windows::Foundation::Uri const& requestUri) const
     {
         void* asyncInfo{};
-        check_hresult(WINRT_IMPL_SHIM(winrt::Windows::Security::Authentication::Web::IWebAuthenticationBrokerStatics)->AuthenticateWithoutCallbackUriAsync(static_cast<uint32_t>(options), *(void**)(&requestUri), &asyncInfo));
+        if constexpr (!std::is_same_v<D, winrt::Windows::Security::Authentication::Web::IWebAuthenticationBrokerStatics>)
+        {
+            winrt::hresult _winrt_cast_result_code;
+            auto const _winrt_casted_result = impl::try_as_with_reason<winrt::Windows::Security::Authentication::Web::IWebAuthenticationBrokerStatics, D const*>(static_cast<D const*>(this), _winrt_cast_result_code);
+            check_hresult(_winrt_cast_result_code);
+            auto const _winrt_abi_type = *(abi_t<winrt::Windows::Security::Authentication::Web::IWebAuthenticationBrokerStatics>**)&_winrt_casted_result;
+            check_hresult(_winrt_abi_type->AuthenticateWithoutCallbackUriAsync(static_cast<uint32_t>(options), *(void**)(&requestUri), &asyncInfo));
+        }
+        else
+        {
+            auto const _winrt_abi_type = *(abi_t<winrt::Windows::Security::Authentication::Web::IWebAuthenticationBrokerStatics>**)this;
+            check_hresult(_winrt_abi_type->AuthenticateWithoutCallbackUriAsync(static_cast<uint32_t>(options), *(void**)(&requestUri), &asyncInfo));
+        }
         return winrt::Windows::Foundation::IAsyncOperation<winrt::Windows::Security::Authentication::Web::WebAuthenticationResult>{ asyncInfo, take_ownership_from_abi };
     }
     template <typename D> auto consume_Windows_Security_Authentication_Web_IWebAuthenticationBrokerStatics<D>::GetCurrentApplicationCallbackUri() const
     {
         void* callbackUri{};
-        check_hresult(WINRT_IMPL_SHIM(winrt::Windows::Security::Authentication::Web::IWebAuthenticationBrokerStatics)->GetCurrentApplicationCallbackUri(&callbackUri));
+        if constexpr (!std::is_same_v<D, winrt::Windows::Security::Authentication::Web::IWebAuthenticationBrokerStatics>)
+        {
+            winrt::hresult _winrt_cast_result_code;
+            auto const _winrt_casted_result = impl::try_as_with_reason<winrt::Windows::Security::Authentication::Web::IWebAuthenticationBrokerStatics, D const*>(static_cast<D const*>(this), _winrt_cast_result_code);
+            check_hresult(_winrt_cast_result_code);
+            auto const _winrt_abi_type = *(abi_t<winrt::Windows::Security::Authentication::Web::IWebAuthenticationBrokerStatics>**)&_winrt_casted_result;
+            check_hresult(_winrt_abi_type->GetCurrentApplicationCallbackUri(&callbackUri));
+        }
+        else
+        {
+            auto const _winrt_abi_type = *(abi_t<winrt::Windows::Security::Authentication::Web::IWebAuthenticationBrokerStatics>**)this;
+            check_hresult(_winrt_abi_type->GetCurrentApplicationCallbackUri(&callbackUri));
+        }
         return winrt::Windows::Foundation::Uri{ callbackUri, take_ownership_from_abi };
     }
     template <typename D> auto consume_Windows_Security_Authentication_Web_IWebAuthenticationBrokerStatics2<D>::AuthenticateAndContinue(winrt::Windows::Foundation::Uri const& requestUri) const
     {
-        check_hresult(WINRT_IMPL_SHIM(winrt::Windows::Security::Authentication::Web::IWebAuthenticationBrokerStatics2)->AuthenticateAndContinue(*(void**)(&requestUri)));
+        if constexpr (!std::is_same_v<D, winrt::Windows::Security::Authentication::Web::IWebAuthenticationBrokerStatics2>)
+        {
+            winrt::hresult _winrt_cast_result_code;
+            auto const _winrt_casted_result = impl::try_as_with_reason<winrt::Windows::Security::Authentication::Web::IWebAuthenticationBrokerStatics2, D const*>(static_cast<D const*>(this), _winrt_cast_result_code);
+            check_hresult(_winrt_cast_result_code);
+            auto const _winrt_abi_type = *(abi_t<winrt::Windows::Security::Authentication::Web::IWebAuthenticationBrokerStatics2>**)&_winrt_casted_result;
+            check_hresult(_winrt_abi_type->AuthenticateAndContinue(*(void**)(&requestUri)));
+        }
+        else
+        {
+            auto const _winrt_abi_type = *(abi_t<winrt::Windows::Security::Authentication::Web::IWebAuthenticationBrokerStatics2>**)this;
+            check_hresult(_winrt_abi_type->AuthenticateAndContinue(*(void**)(&requestUri)));
+        }
     }
     template <typename D> auto consume_Windows_Security_Authentication_Web_IWebAuthenticationBrokerStatics2<D>::AuthenticateAndContinue(winrt::Windows::Foundation::Uri const& requestUri, winrt::Windows::Foundation::Uri const& callbackUri) const
     {
-        check_hresult(WINRT_IMPL_SHIM(winrt::Windows::Security::Authentication::Web::IWebAuthenticationBrokerStatics2)->AuthenticateWithCallbackUriAndContinue(*(void**)(&requestUri), *(void**)(&callbackUri)));
+        if constexpr (!std::is_same_v<D, winrt::Windows::Security::Authentication::Web::IWebAuthenticationBrokerStatics2>)
+        {
+            winrt::hresult _winrt_cast_result_code;
+            auto const _winrt_casted_result = impl::try_as_with_reason<winrt::Windows::Security::Authentication::Web::IWebAuthenticationBrokerStatics2, D const*>(static_cast<D const*>(this), _winrt_cast_result_code);
+            check_hresult(_winrt_cast_result_code);
+            auto const _winrt_abi_type = *(abi_t<winrt::Windows::Security::Authentication::Web::IWebAuthenticationBrokerStatics2>**)&_winrt_casted_result;
+            check_hresult(_winrt_abi_type->AuthenticateWithCallbackUriAndContinue(*(void**)(&requestUri), *(void**)(&callbackUri)));
+        }
+        else
+        {
+            auto const _winrt_abi_type = *(abi_t<winrt::Windows::Security::Authentication::Web::IWebAuthenticationBrokerStatics2>**)this;
+            check_hresult(_winrt_abi_type->AuthenticateWithCallbackUriAndContinue(*(void**)(&requestUri), *(void**)(&callbackUri)));
+        }
     }
     template <typename D> auto consume_Windows_Security_Authentication_Web_IWebAuthenticationBrokerStatics2<D>::AuthenticateAndContinue(winrt::Windows::Foundation::Uri const& requestUri, winrt::Windows::Foundation::Uri const& callbackUri, winrt::Windows::Foundation::Collections::ValueSet const& continuationData, winrt::Windows::Security::Authentication::Web::WebAuthenticationOptions const& options) const
     {
-        check_hresult(WINRT_IMPL_SHIM(winrt::Windows::Security::Authentication::Web::IWebAuthenticationBrokerStatics2)->AuthenticateWithCallbackUriContinuationDataAndOptionsAndContinue(*(void**)(&requestUri), *(void**)(&callbackUri), *(void**)(&continuationData), static_cast<uint32_t>(options)));
+        if constexpr (!std::is_same_v<D, winrt::Windows::Security::Authentication::Web::IWebAuthenticationBrokerStatics2>)
+        {
+            winrt::hresult _winrt_cast_result_code;
+            auto const _winrt_casted_result = impl::try_as_with_reason<winrt::Windows::Security::Authentication::Web::IWebAuthenticationBrokerStatics2, D const*>(static_cast<D const*>(this), _winrt_cast_result_code);
+            check_hresult(_winrt_cast_result_code);
+            auto const _winrt_abi_type = *(abi_t<winrt::Windows::Security::Authentication::Web::IWebAuthenticationBrokerStatics2>**)&_winrt_casted_result;
+            check_hresult(_winrt_abi_type->AuthenticateWithCallbackUriContinuationDataAndOptionsAndContinue(*(void**)(&requestUri), *(void**)(&callbackUri), *(void**)(&continuationData), static_cast<uint32_t>(options)));
+        }
+        else
+        {
+            auto const _winrt_abi_type = *(abi_t<winrt::Windows::Security::Authentication::Web::IWebAuthenticationBrokerStatics2>**)this;
+            check_hresult(_winrt_abi_type->AuthenticateWithCallbackUriContinuationDataAndOptionsAndContinue(*(void**)(&requestUri), *(void**)(&callbackUri), *(void**)(&continuationData), static_cast<uint32_t>(options)));
+        }
     }
     template <typename D> auto consume_Windows_Security_Authentication_Web_IWebAuthenticationBrokerStatics2<D>::AuthenticateSilentlyAsync(winrt::Windows::Foundation::Uri const& requestUri) const
     {
         void* asyncInfo{};
-        check_hresult(WINRT_IMPL_SHIM(winrt::Windows::Security::Authentication::Web::IWebAuthenticationBrokerStatics2)->AuthenticateSilentlyAsync(*(void**)(&requestUri), &asyncInfo));
+        if constexpr (!std::is_same_v<D, winrt::Windows::Security::Authentication::Web::IWebAuthenticationBrokerStatics2>)
+        {
+            winrt::hresult _winrt_cast_result_code;
+            auto const _winrt_casted_result = impl::try_as_with_reason<winrt::Windows::Security::Authentication::Web::IWebAuthenticationBrokerStatics2, D const*>(static_cast<D const*>(this), _winrt_cast_result_code);
+            check_hresult(_winrt_cast_result_code);
+            auto const _winrt_abi_type = *(abi_t<winrt::Windows::Security::Authentication::Web::IWebAuthenticationBrokerStatics2>**)&_winrt_casted_result;
+            check_hresult(_winrt_abi_type->AuthenticateSilentlyAsync(*(void**)(&requestUri), &asyncInfo));
+        }
+        else
+        {
+            auto const _winrt_abi_type = *(abi_t<winrt::Windows::Security::Authentication::Web::IWebAuthenticationBrokerStatics2>**)this;
+            check_hresult(_winrt_abi_type->AuthenticateSilentlyAsync(*(void**)(&requestUri), &asyncInfo));
+        }
         return winrt::Windows::Foundation::IAsyncOperation<winrt::Windows::Security::Authentication::Web::WebAuthenticationResult>{ asyncInfo, take_ownership_from_abi };
     }
     template <typename D> auto consume_Windows_Security_Authentication_Web_IWebAuthenticationBrokerStatics2<D>::AuthenticateSilentlyAsync(winrt::Windows::Foundation::Uri const& requestUri, winrt::Windows::Security::Authentication::Web::WebAuthenticationOptions const& options) const
     {
         void* asyncInfo{};
-        check_hresult(WINRT_IMPL_SHIM(winrt::Windows::Security::Authentication::Web::IWebAuthenticationBrokerStatics2)->AuthenticateSilentlyWithOptionsAsync(*(void**)(&requestUri), static_cast<uint32_t>(options), &asyncInfo));
+        if constexpr (!std::is_same_v<D, winrt::Windows::Security::Authentication::Web::IWebAuthenticationBrokerStatics2>)
+        {
+            winrt::hresult _winrt_cast_result_code;
+            auto const _winrt_casted_result = impl::try_as_with_reason<winrt::Windows::Security::Authentication::Web::IWebAuthenticationBrokerStatics2, D const*>(static_cast<D const*>(this), _winrt_cast_result_code);
+            check_hresult(_winrt_cast_result_code);
+            auto const _winrt_abi_type = *(abi_t<winrt::Windows::Security::Authentication::Web::IWebAuthenticationBrokerStatics2>**)&_winrt_casted_result;
+            check_hresult(_winrt_abi_type->AuthenticateSilentlyWithOptionsAsync(*(void**)(&requestUri), static_cast<uint32_t>(options), &asyncInfo));
+        }
+        else
+        {
+            auto const _winrt_abi_type = *(abi_t<winrt::Windows::Security::Authentication::Web::IWebAuthenticationBrokerStatics2>**)this;
+            check_hresult(_winrt_abi_type->AuthenticateSilentlyWithOptionsAsync(*(void**)(&requestUri), static_cast<uint32_t>(options), &asyncInfo));
+        }
         return winrt::Windows::Foundation::IAsyncOperation<winrt::Windows::Security::Authentication::Web::WebAuthenticationResult>{ asyncInfo, take_ownership_from_abi };
     }
     template <typename D> auto consume_Windows_Security_Authentication_Web_IWebAuthenticationResult<D>::ResponseData() const
     {
         void* value{};
-        check_hresult(WINRT_IMPL_SHIM(winrt::Windows::Security::Authentication::Web::IWebAuthenticationResult)->get_ResponseData(&value));
+        if constexpr (!std::is_same_v<D, winrt::Windows::Security::Authentication::Web::IWebAuthenticationResult>)
+        {
+            winrt::hresult _winrt_cast_result_code;
+            auto const _winrt_casted_result = impl::try_as_with_reason<winrt::Windows::Security::Authentication::Web::IWebAuthenticationResult, D const*>(static_cast<D const*>(this), _winrt_cast_result_code);
+            check_hresult(_winrt_cast_result_code);
+            auto const _winrt_abi_type = *(abi_t<winrt::Windows::Security::Authentication::Web::IWebAuthenticationResult>**)&_winrt_casted_result;
+            check_hresult(_winrt_abi_type->get_ResponseData(&value));
+        }
+        else
+        {
+            auto const _winrt_abi_type = *(abi_t<winrt::Windows::Security::Authentication::Web::IWebAuthenticationResult>**)this;
+            check_hresult(_winrt_abi_type->get_ResponseData(&value));
+        }
         return hstring{ value, take_ownership_from_abi };
     }
     template <typename D> auto consume_Windows_Security_Authentication_Web_IWebAuthenticationResult<D>::ResponseStatus() const
     {
         winrt::Windows::Security::Authentication::Web::WebAuthenticationStatus value{};
-        check_hresult(WINRT_IMPL_SHIM(winrt::Windows::Security::Authentication::Web::IWebAuthenticationResult)->get_ResponseStatus(reinterpret_cast<int32_t*>(&value)));
+        if constexpr (!std::is_same_v<D, winrt::Windows::Security::Authentication::Web::IWebAuthenticationResult>)
+        {
+            winrt::hresult _winrt_cast_result_code;
+            auto const _winrt_casted_result = impl::try_as_with_reason<winrt::Windows::Security::Authentication::Web::IWebAuthenticationResult, D const*>(static_cast<D const*>(this), _winrt_cast_result_code);
+            check_hresult(_winrt_cast_result_code);
+            auto const _winrt_abi_type = *(abi_t<winrt::Windows::Security::Authentication::Web::IWebAuthenticationResult>**)&_winrt_casted_result;
+            check_hresult(_winrt_abi_type->get_ResponseStatus(reinterpret_cast<int32_t*>(&value)));
+        }
+        else
+        {
+            auto const _winrt_abi_type = *(abi_t<winrt::Windows::Security::Authentication::Web::IWebAuthenticationResult>**)this;
+            check_hresult(_winrt_abi_type->get_ResponseStatus(reinterpret_cast<int32_t*>(&value)));
+        }
         return value;
     }
     template <typename D> auto consume_Windows_Security_Authentication_Web_IWebAuthenticationResult<D>::ResponseErrorDetail() const
     {
         uint32_t value{};
-        check_hresult(WINRT_IMPL_SHIM(winrt::Windows::Security::Authentication::Web::IWebAuthenticationResult)->get_ResponseErrorDetail(&value));
+        if constexpr (!std::is_same_v<D, winrt::Windows::Security::Authentication::Web::IWebAuthenticationResult>)
+        {
+            winrt::hresult _winrt_cast_result_code;
+            auto const _winrt_casted_result = impl::try_as_with_reason<winrt::Windows::Security::Authentication::Web::IWebAuthenticationResult, D const*>(static_cast<D const*>(this), _winrt_cast_result_code);
+            check_hresult(_winrt_cast_result_code);
+            auto const _winrt_abi_type = *(abi_t<winrt::Windows::Security::Authentication::Web::IWebAuthenticationResult>**)&_winrt_casted_result;
+            check_hresult(_winrt_abi_type->get_ResponseErrorDetail(&value));
+        }
+        else
+        {
+            auto const _winrt_abi_type = *(abi_t<winrt::Windows::Security::Authentication::Web::IWebAuthenticationResult>**)this;
+            check_hresult(_winrt_abi_type->get_ResponseErrorDetail(&value));
+        }
         return value;
     }
 #ifndef WINRT_LEAN_AND_MEAN
