@@ -1,4 +1,4 @@
-// C++/WinRT v2.0.240111.5
+// C++/WinRT v2.0.250303.1
 
 // SPDX-License-Identifier: MIT OR Apache-2.0
 // SPDX-FileCopyrightText: Copyright (c) Microsoft Corporation
@@ -10,8 +10,8 @@
 #ifndef WINRT_Windows_Web_AtomPub_H
 #define WINRT_Windows_Web_AtomPub_H
 #include "winrt/base.h"
-static_assert(winrt::check_version(CPPWINRT_VERSION, "2.0.240111.5"), "Mismatched C++/WinRT headers.");
-#define CPPWINRT_VERSION "2.0.240111.5"
+static_assert(winrt::check_version(CPPWINRT_VERSION, "2.0.250303.1"), "Mismatched C++/WinRT headers.");
+#define CPPWINRT_VERSION "2.0.250303.1"
 #include "winrt/Windows.Web.h"
 #include "winrt/impl/Windows.Foundation.2.h"
 #include "winrt/impl/Windows.Foundation.Collections.2.h"
@@ -24,113 +24,341 @@ namespace winrt::impl
     template <typename D> auto consume_Windows_Web_AtomPub_IAtomPubClient<D>::RetrieveServiceDocumentAsync(winrt::Windows::Foundation::Uri const& uri) const
     {
         void* operation{};
-        check_hresult(WINRT_IMPL_SHIM(winrt::Windows::Web::AtomPub::IAtomPubClient)->RetrieveServiceDocumentAsync(*(void**)(&uri), &operation));
+        if constexpr (!std::is_same_v<D, winrt::Windows::Web::AtomPub::IAtomPubClient>)
+        {
+            winrt::hresult _winrt_cast_result_code;
+            auto const _winrt_casted_result = impl::try_as_with_reason<winrt::Windows::Web::AtomPub::IAtomPubClient, D const*>(static_cast<D const*>(this), _winrt_cast_result_code);
+            check_hresult(_winrt_cast_result_code);
+            auto const _winrt_abi_type = *(abi_t<winrt::Windows::Web::AtomPub::IAtomPubClient>**)&_winrt_casted_result;
+            check_hresult(_winrt_abi_type->RetrieveServiceDocumentAsync(*(void**)(&uri), &operation));
+        }
+        else
+        {
+            auto const _winrt_abi_type = *(abi_t<winrt::Windows::Web::AtomPub::IAtomPubClient>**)this;
+            check_hresult(_winrt_abi_type->RetrieveServiceDocumentAsync(*(void**)(&uri), &operation));
+        }
         return winrt::Windows::Foundation::IAsyncOperationWithProgress<winrt::Windows::Web::AtomPub::ServiceDocument, winrt::Windows::Web::Syndication::RetrievalProgress>{ operation, take_ownership_from_abi };
     }
     template <typename D> auto consume_Windows_Web_AtomPub_IAtomPubClient<D>::RetrieveMediaResourceAsync(winrt::Windows::Foundation::Uri const& uri) const
     {
         void* operation{};
-        check_hresult(WINRT_IMPL_SHIM(winrt::Windows::Web::AtomPub::IAtomPubClient)->RetrieveMediaResourceAsync(*(void**)(&uri), &operation));
+        if constexpr (!std::is_same_v<D, winrt::Windows::Web::AtomPub::IAtomPubClient>)
+        {
+            winrt::hresult _winrt_cast_result_code;
+            auto const _winrt_casted_result = impl::try_as_with_reason<winrt::Windows::Web::AtomPub::IAtomPubClient, D const*>(static_cast<D const*>(this), _winrt_cast_result_code);
+            check_hresult(_winrt_cast_result_code);
+            auto const _winrt_abi_type = *(abi_t<winrt::Windows::Web::AtomPub::IAtomPubClient>**)&_winrt_casted_result;
+            check_hresult(_winrt_abi_type->RetrieveMediaResourceAsync(*(void**)(&uri), &operation));
+        }
+        else
+        {
+            auto const _winrt_abi_type = *(abi_t<winrt::Windows::Web::AtomPub::IAtomPubClient>**)this;
+            check_hresult(_winrt_abi_type->RetrieveMediaResourceAsync(*(void**)(&uri), &operation));
+        }
         return winrt::Windows::Foundation::IAsyncOperationWithProgress<winrt::Windows::Storage::Streams::IInputStream, winrt::Windows::Web::Syndication::RetrievalProgress>{ operation, take_ownership_from_abi };
     }
     template <typename D> auto consume_Windows_Web_AtomPub_IAtomPubClient<D>::RetrieveResourceAsync(winrt::Windows::Foundation::Uri const& uri) const
     {
         void* operation{};
-        check_hresult(WINRT_IMPL_SHIM(winrt::Windows::Web::AtomPub::IAtomPubClient)->RetrieveResourceAsync(*(void**)(&uri), &operation));
+        if constexpr (!std::is_same_v<D, winrt::Windows::Web::AtomPub::IAtomPubClient>)
+        {
+            winrt::hresult _winrt_cast_result_code;
+            auto const _winrt_casted_result = impl::try_as_with_reason<winrt::Windows::Web::AtomPub::IAtomPubClient, D const*>(static_cast<D const*>(this), _winrt_cast_result_code);
+            check_hresult(_winrt_cast_result_code);
+            auto const _winrt_abi_type = *(abi_t<winrt::Windows::Web::AtomPub::IAtomPubClient>**)&_winrt_casted_result;
+            check_hresult(_winrt_abi_type->RetrieveResourceAsync(*(void**)(&uri), &operation));
+        }
+        else
+        {
+            auto const _winrt_abi_type = *(abi_t<winrt::Windows::Web::AtomPub::IAtomPubClient>**)this;
+            check_hresult(_winrt_abi_type->RetrieveResourceAsync(*(void**)(&uri), &operation));
+        }
         return winrt::Windows::Foundation::IAsyncOperationWithProgress<winrt::Windows::Web::Syndication::SyndicationItem, winrt::Windows::Web::Syndication::RetrievalProgress>{ operation, take_ownership_from_abi };
     }
     template <typename D> auto consume_Windows_Web_AtomPub_IAtomPubClient<D>::CreateResourceAsync(winrt::Windows::Foundation::Uri const& uri, param::hstring const& description, winrt::Windows::Web::Syndication::SyndicationItem const& item) const
     {
         void* operation{};
-        check_hresult(WINRT_IMPL_SHIM(winrt::Windows::Web::AtomPub::IAtomPubClient)->CreateResourceAsync(*(void**)(&uri), *(void**)(&description), *(void**)(&item), &operation));
+        if constexpr (!std::is_same_v<D, winrt::Windows::Web::AtomPub::IAtomPubClient>)
+        {
+            winrt::hresult _winrt_cast_result_code;
+            auto const _winrt_casted_result = impl::try_as_with_reason<winrt::Windows::Web::AtomPub::IAtomPubClient, D const*>(static_cast<D const*>(this), _winrt_cast_result_code);
+            check_hresult(_winrt_cast_result_code);
+            auto const _winrt_abi_type = *(abi_t<winrt::Windows::Web::AtomPub::IAtomPubClient>**)&_winrt_casted_result;
+            check_hresult(_winrt_abi_type->CreateResourceAsync(*(void**)(&uri), *(void**)(&description), *(void**)(&item), &operation));
+        }
+        else
+        {
+            auto const _winrt_abi_type = *(abi_t<winrt::Windows::Web::AtomPub::IAtomPubClient>**)this;
+            check_hresult(_winrt_abi_type->CreateResourceAsync(*(void**)(&uri), *(void**)(&description), *(void**)(&item), &operation));
+        }
         return winrt::Windows::Foundation::IAsyncOperationWithProgress<winrt::Windows::Web::Syndication::SyndicationItem, winrt::Windows::Web::Syndication::TransferProgress>{ operation, take_ownership_from_abi };
     }
     template <typename D> auto consume_Windows_Web_AtomPub_IAtomPubClient<D>::CreateMediaResourceAsync(winrt::Windows::Foundation::Uri const& uri, param::hstring const& mediaType, param::hstring const& description, winrt::Windows::Storage::Streams::IInputStream const& mediaStream) const
     {
         void* operation{};
-        check_hresult(WINRT_IMPL_SHIM(winrt::Windows::Web::AtomPub::IAtomPubClient)->CreateMediaResourceAsync(*(void**)(&uri), *(void**)(&mediaType), *(void**)(&description), *(void**)(&mediaStream), &operation));
+        if constexpr (!std::is_same_v<D, winrt::Windows::Web::AtomPub::IAtomPubClient>)
+        {
+            winrt::hresult _winrt_cast_result_code;
+            auto const _winrt_casted_result = impl::try_as_with_reason<winrt::Windows::Web::AtomPub::IAtomPubClient, D const*>(static_cast<D const*>(this), _winrt_cast_result_code);
+            check_hresult(_winrt_cast_result_code);
+            auto const _winrt_abi_type = *(abi_t<winrt::Windows::Web::AtomPub::IAtomPubClient>**)&_winrt_casted_result;
+            check_hresult(_winrt_abi_type->CreateMediaResourceAsync(*(void**)(&uri), *(void**)(&mediaType), *(void**)(&description), *(void**)(&mediaStream), &operation));
+        }
+        else
+        {
+            auto const _winrt_abi_type = *(abi_t<winrt::Windows::Web::AtomPub::IAtomPubClient>**)this;
+            check_hresult(_winrt_abi_type->CreateMediaResourceAsync(*(void**)(&uri), *(void**)(&mediaType), *(void**)(&description), *(void**)(&mediaStream), &operation));
+        }
         return winrt::Windows::Foundation::IAsyncOperationWithProgress<winrt::Windows::Web::Syndication::SyndicationItem, winrt::Windows::Web::Syndication::TransferProgress>{ operation, take_ownership_from_abi };
     }
     template <typename D> auto consume_Windows_Web_AtomPub_IAtomPubClient<D>::UpdateMediaResourceAsync(winrt::Windows::Foundation::Uri const& uri, param::hstring const& mediaType, winrt::Windows::Storage::Streams::IInputStream const& mediaStream) const
     {
         void* operation{};
-        check_hresult(WINRT_IMPL_SHIM(winrt::Windows::Web::AtomPub::IAtomPubClient)->UpdateMediaResourceAsync(*(void**)(&uri), *(void**)(&mediaType), *(void**)(&mediaStream), &operation));
+        if constexpr (!std::is_same_v<D, winrt::Windows::Web::AtomPub::IAtomPubClient>)
+        {
+            winrt::hresult _winrt_cast_result_code;
+            auto const _winrt_casted_result = impl::try_as_with_reason<winrt::Windows::Web::AtomPub::IAtomPubClient, D const*>(static_cast<D const*>(this), _winrt_cast_result_code);
+            check_hresult(_winrt_cast_result_code);
+            auto const _winrt_abi_type = *(abi_t<winrt::Windows::Web::AtomPub::IAtomPubClient>**)&_winrt_casted_result;
+            check_hresult(_winrt_abi_type->UpdateMediaResourceAsync(*(void**)(&uri), *(void**)(&mediaType), *(void**)(&mediaStream), &operation));
+        }
+        else
+        {
+            auto const _winrt_abi_type = *(abi_t<winrt::Windows::Web::AtomPub::IAtomPubClient>**)this;
+            check_hresult(_winrt_abi_type->UpdateMediaResourceAsync(*(void**)(&uri), *(void**)(&mediaType), *(void**)(&mediaStream), &operation));
+        }
         return winrt::Windows::Foundation::IAsyncActionWithProgress<winrt::Windows::Web::Syndication::TransferProgress>{ operation, take_ownership_from_abi };
     }
     template <typename D> auto consume_Windows_Web_AtomPub_IAtomPubClient<D>::UpdateResourceAsync(winrt::Windows::Foundation::Uri const& uri, winrt::Windows::Web::Syndication::SyndicationItem const& item) const
     {
         void* operation{};
-        check_hresult(WINRT_IMPL_SHIM(winrt::Windows::Web::AtomPub::IAtomPubClient)->UpdateResourceAsync(*(void**)(&uri), *(void**)(&item), &operation));
+        if constexpr (!std::is_same_v<D, winrt::Windows::Web::AtomPub::IAtomPubClient>)
+        {
+            winrt::hresult _winrt_cast_result_code;
+            auto const _winrt_casted_result = impl::try_as_with_reason<winrt::Windows::Web::AtomPub::IAtomPubClient, D const*>(static_cast<D const*>(this), _winrt_cast_result_code);
+            check_hresult(_winrt_cast_result_code);
+            auto const _winrt_abi_type = *(abi_t<winrt::Windows::Web::AtomPub::IAtomPubClient>**)&_winrt_casted_result;
+            check_hresult(_winrt_abi_type->UpdateResourceAsync(*(void**)(&uri), *(void**)(&item), &operation));
+        }
+        else
+        {
+            auto const _winrt_abi_type = *(abi_t<winrt::Windows::Web::AtomPub::IAtomPubClient>**)this;
+            check_hresult(_winrt_abi_type->UpdateResourceAsync(*(void**)(&uri), *(void**)(&item), &operation));
+        }
         return winrt::Windows::Foundation::IAsyncActionWithProgress<winrt::Windows::Web::Syndication::TransferProgress>{ operation, take_ownership_from_abi };
     }
     template <typename D> auto consume_Windows_Web_AtomPub_IAtomPubClient<D>::UpdateResourceItemAsync(winrt::Windows::Web::Syndication::SyndicationItem const& item) const
     {
         void* operation{};
-        check_hresult(WINRT_IMPL_SHIM(winrt::Windows::Web::AtomPub::IAtomPubClient)->UpdateResourceItemAsync(*(void**)(&item), &operation));
+        if constexpr (!std::is_same_v<D, winrt::Windows::Web::AtomPub::IAtomPubClient>)
+        {
+            winrt::hresult _winrt_cast_result_code;
+            auto const _winrt_casted_result = impl::try_as_with_reason<winrt::Windows::Web::AtomPub::IAtomPubClient, D const*>(static_cast<D const*>(this), _winrt_cast_result_code);
+            check_hresult(_winrt_cast_result_code);
+            auto const _winrt_abi_type = *(abi_t<winrt::Windows::Web::AtomPub::IAtomPubClient>**)&_winrt_casted_result;
+            check_hresult(_winrt_abi_type->UpdateResourceItemAsync(*(void**)(&item), &operation));
+        }
+        else
+        {
+            auto const _winrt_abi_type = *(abi_t<winrt::Windows::Web::AtomPub::IAtomPubClient>**)this;
+            check_hresult(_winrt_abi_type->UpdateResourceItemAsync(*(void**)(&item), &operation));
+        }
         return winrt::Windows::Foundation::IAsyncActionWithProgress<winrt::Windows::Web::Syndication::TransferProgress>{ operation, take_ownership_from_abi };
     }
     template <typename D> auto consume_Windows_Web_AtomPub_IAtomPubClient<D>::DeleteResourceAsync(winrt::Windows::Foundation::Uri const& uri) const
     {
         void* operation{};
-        check_hresult(WINRT_IMPL_SHIM(winrt::Windows::Web::AtomPub::IAtomPubClient)->DeleteResourceAsync(*(void**)(&uri), &operation));
+        if constexpr (!std::is_same_v<D, winrt::Windows::Web::AtomPub::IAtomPubClient>)
+        {
+            winrt::hresult _winrt_cast_result_code;
+            auto const _winrt_casted_result = impl::try_as_with_reason<winrt::Windows::Web::AtomPub::IAtomPubClient, D const*>(static_cast<D const*>(this), _winrt_cast_result_code);
+            check_hresult(_winrt_cast_result_code);
+            auto const _winrt_abi_type = *(abi_t<winrt::Windows::Web::AtomPub::IAtomPubClient>**)&_winrt_casted_result;
+            check_hresult(_winrt_abi_type->DeleteResourceAsync(*(void**)(&uri), &operation));
+        }
+        else
+        {
+            auto const _winrt_abi_type = *(abi_t<winrt::Windows::Web::AtomPub::IAtomPubClient>**)this;
+            check_hresult(_winrt_abi_type->DeleteResourceAsync(*(void**)(&uri), &operation));
+        }
         return winrt::Windows::Foundation::IAsyncActionWithProgress<winrt::Windows::Web::Syndication::TransferProgress>{ operation, take_ownership_from_abi };
     }
     template <typename D> auto consume_Windows_Web_AtomPub_IAtomPubClient<D>::DeleteResourceItemAsync(winrt::Windows::Web::Syndication::SyndicationItem const& item) const
     {
         void* operation{};
-        check_hresult(WINRT_IMPL_SHIM(winrt::Windows::Web::AtomPub::IAtomPubClient)->DeleteResourceItemAsync(*(void**)(&item), &operation));
+        if constexpr (!std::is_same_v<D, winrt::Windows::Web::AtomPub::IAtomPubClient>)
+        {
+            winrt::hresult _winrt_cast_result_code;
+            auto const _winrt_casted_result = impl::try_as_with_reason<winrt::Windows::Web::AtomPub::IAtomPubClient, D const*>(static_cast<D const*>(this), _winrt_cast_result_code);
+            check_hresult(_winrt_cast_result_code);
+            auto const _winrt_abi_type = *(abi_t<winrt::Windows::Web::AtomPub::IAtomPubClient>**)&_winrt_casted_result;
+            check_hresult(_winrt_abi_type->DeleteResourceItemAsync(*(void**)(&item), &operation));
+        }
+        else
+        {
+            auto const _winrt_abi_type = *(abi_t<winrt::Windows::Web::AtomPub::IAtomPubClient>**)this;
+            check_hresult(_winrt_abi_type->DeleteResourceItemAsync(*(void**)(&item), &operation));
+        }
         return winrt::Windows::Foundation::IAsyncActionWithProgress<winrt::Windows::Web::Syndication::TransferProgress>{ operation, take_ownership_from_abi };
     }
     template <typename D> auto consume_Windows_Web_AtomPub_IAtomPubClient<D>::CancelAsyncOperations() const
     {
-        check_hresult(WINRT_IMPL_SHIM(winrt::Windows::Web::AtomPub::IAtomPubClient)->CancelAsyncOperations());
+        if constexpr (!std::is_same_v<D, winrt::Windows::Web::AtomPub::IAtomPubClient>)
+        {
+            winrt::hresult _winrt_cast_result_code;
+            auto const _winrt_casted_result = impl::try_as_with_reason<winrt::Windows::Web::AtomPub::IAtomPubClient, D const*>(static_cast<D const*>(this), _winrt_cast_result_code);
+            check_hresult(_winrt_cast_result_code);
+            auto const _winrt_abi_type = *(abi_t<winrt::Windows::Web::AtomPub::IAtomPubClient>**)&_winrt_casted_result;
+            check_hresult(_winrt_abi_type->CancelAsyncOperations());
+        }
+        else
+        {
+            auto const _winrt_abi_type = *(abi_t<winrt::Windows::Web::AtomPub::IAtomPubClient>**)this;
+            check_hresult(_winrt_abi_type->CancelAsyncOperations());
+        }
     }
     template <typename D> auto consume_Windows_Web_AtomPub_IAtomPubClientFactory<D>::CreateAtomPubClientWithCredentials(winrt::Windows::Security::Credentials::PasswordCredential const& serverCredential) const
     {
         void* atomPubClient{};
-        check_hresult(WINRT_IMPL_SHIM(winrt::Windows::Web::AtomPub::IAtomPubClientFactory)->CreateAtomPubClientWithCredentials(*(void**)(&serverCredential), &atomPubClient));
+        if constexpr (!std::is_same_v<D, winrt::Windows::Web::AtomPub::IAtomPubClientFactory>)
+        {
+            winrt::hresult _winrt_cast_result_code;
+            auto const _winrt_casted_result = impl::try_as_with_reason<winrt::Windows::Web::AtomPub::IAtomPubClientFactory, D const*>(static_cast<D const*>(this), _winrt_cast_result_code);
+            check_hresult(_winrt_cast_result_code);
+            auto const _winrt_abi_type = *(abi_t<winrt::Windows::Web::AtomPub::IAtomPubClientFactory>**)&_winrt_casted_result;
+            check_hresult(_winrt_abi_type->CreateAtomPubClientWithCredentials(*(void**)(&serverCredential), &atomPubClient));
+        }
+        else
+        {
+            auto const _winrt_abi_type = *(abi_t<winrt::Windows::Web::AtomPub::IAtomPubClientFactory>**)this;
+            check_hresult(_winrt_abi_type->CreateAtomPubClientWithCredentials(*(void**)(&serverCredential), &atomPubClient));
+        }
         return winrt::Windows::Web::AtomPub::AtomPubClient{ atomPubClient, take_ownership_from_abi };
     }
     template <typename D> auto consume_Windows_Web_AtomPub_IResourceCollection<D>::Title() const
     {
         void* value{};
-        check_hresult(WINRT_IMPL_SHIM(winrt::Windows::Web::AtomPub::IResourceCollection)->get_Title(&value));
+        if constexpr (!std::is_same_v<D, winrt::Windows::Web::AtomPub::IResourceCollection>)
+        {
+            winrt::hresult _winrt_cast_result_code;
+            auto const _winrt_casted_result = impl::try_as_with_reason<winrt::Windows::Web::AtomPub::IResourceCollection, D const*>(static_cast<D const*>(this), _winrt_cast_result_code);
+            check_hresult(_winrt_cast_result_code);
+            auto const _winrt_abi_type = *(abi_t<winrt::Windows::Web::AtomPub::IResourceCollection>**)&_winrt_casted_result;
+            check_hresult(_winrt_abi_type->get_Title(&value));
+        }
+        else
+        {
+            auto const _winrt_abi_type = *(abi_t<winrt::Windows::Web::AtomPub::IResourceCollection>**)this;
+            check_hresult(_winrt_abi_type->get_Title(&value));
+        }
         return winrt::Windows::Web::Syndication::ISyndicationText{ value, take_ownership_from_abi };
     }
     template <typename D> auto consume_Windows_Web_AtomPub_IResourceCollection<D>::Uri() const
     {
         void* value{};
-        check_hresult(WINRT_IMPL_SHIM(winrt::Windows::Web::AtomPub::IResourceCollection)->get_Uri(&value));
+        if constexpr (!std::is_same_v<D, winrt::Windows::Web::AtomPub::IResourceCollection>)
+        {
+            winrt::hresult _winrt_cast_result_code;
+            auto const _winrt_casted_result = impl::try_as_with_reason<winrt::Windows::Web::AtomPub::IResourceCollection, D const*>(static_cast<D const*>(this), _winrt_cast_result_code);
+            check_hresult(_winrt_cast_result_code);
+            auto const _winrt_abi_type = *(abi_t<winrt::Windows::Web::AtomPub::IResourceCollection>**)&_winrt_casted_result;
+            check_hresult(_winrt_abi_type->get_Uri(&value));
+        }
+        else
+        {
+            auto const _winrt_abi_type = *(abi_t<winrt::Windows::Web::AtomPub::IResourceCollection>**)this;
+            check_hresult(_winrt_abi_type->get_Uri(&value));
+        }
         return winrt::Windows::Foundation::Uri{ value, take_ownership_from_abi };
     }
     template <typename D> auto consume_Windows_Web_AtomPub_IResourceCollection<D>::Categories() const
     {
         void* value{};
-        check_hresult(WINRT_IMPL_SHIM(winrt::Windows::Web::AtomPub::IResourceCollection)->get_Categories(&value));
+        if constexpr (!std::is_same_v<D, winrt::Windows::Web::AtomPub::IResourceCollection>)
+        {
+            winrt::hresult _winrt_cast_result_code;
+            auto const _winrt_casted_result = impl::try_as_with_reason<winrt::Windows::Web::AtomPub::IResourceCollection, D const*>(static_cast<D const*>(this), _winrt_cast_result_code);
+            check_hresult(_winrt_cast_result_code);
+            auto const _winrt_abi_type = *(abi_t<winrt::Windows::Web::AtomPub::IResourceCollection>**)&_winrt_casted_result;
+            check_hresult(_winrt_abi_type->get_Categories(&value));
+        }
+        else
+        {
+            auto const _winrt_abi_type = *(abi_t<winrt::Windows::Web::AtomPub::IResourceCollection>**)this;
+            check_hresult(_winrt_abi_type->get_Categories(&value));
+        }
         return winrt::Windows::Foundation::Collections::IVectorView<winrt::Windows::Web::Syndication::SyndicationCategory>{ value, take_ownership_from_abi };
     }
     template <typename D> auto consume_Windows_Web_AtomPub_IResourceCollection<D>::Accepts() const
     {
         void* value{};
-        check_hresult(WINRT_IMPL_SHIM(winrt::Windows::Web::AtomPub::IResourceCollection)->get_Accepts(&value));
+        if constexpr (!std::is_same_v<D, winrt::Windows::Web::AtomPub::IResourceCollection>)
+        {
+            winrt::hresult _winrt_cast_result_code;
+            auto const _winrt_casted_result = impl::try_as_with_reason<winrt::Windows::Web::AtomPub::IResourceCollection, D const*>(static_cast<D const*>(this), _winrt_cast_result_code);
+            check_hresult(_winrt_cast_result_code);
+            auto const _winrt_abi_type = *(abi_t<winrt::Windows::Web::AtomPub::IResourceCollection>**)&_winrt_casted_result;
+            check_hresult(_winrt_abi_type->get_Accepts(&value));
+        }
+        else
+        {
+            auto const _winrt_abi_type = *(abi_t<winrt::Windows::Web::AtomPub::IResourceCollection>**)this;
+            check_hresult(_winrt_abi_type->get_Accepts(&value));
+        }
         return winrt::Windows::Foundation::Collections::IVectorView<hstring>{ value, take_ownership_from_abi };
     }
     template <typename D> auto consume_Windows_Web_AtomPub_IServiceDocument<D>::Workspaces() const
     {
         void* value{};
-        check_hresult(WINRT_IMPL_SHIM(winrt::Windows::Web::AtomPub::IServiceDocument)->get_Workspaces(&value));
+        if constexpr (!std::is_same_v<D, winrt::Windows::Web::AtomPub::IServiceDocument>)
+        {
+            winrt::hresult _winrt_cast_result_code;
+            auto const _winrt_casted_result = impl::try_as_with_reason<winrt::Windows::Web::AtomPub::IServiceDocument, D const*>(static_cast<D const*>(this), _winrt_cast_result_code);
+            check_hresult(_winrt_cast_result_code);
+            auto const _winrt_abi_type = *(abi_t<winrt::Windows::Web::AtomPub::IServiceDocument>**)&_winrt_casted_result;
+            check_hresult(_winrt_abi_type->get_Workspaces(&value));
+        }
+        else
+        {
+            auto const _winrt_abi_type = *(abi_t<winrt::Windows::Web::AtomPub::IServiceDocument>**)this;
+            check_hresult(_winrt_abi_type->get_Workspaces(&value));
+        }
         return winrt::Windows::Foundation::Collections::IVectorView<winrt::Windows::Web::AtomPub::Workspace>{ value, take_ownership_from_abi };
     }
     template <typename D> auto consume_Windows_Web_AtomPub_IWorkspace<D>::Title() const
     {
         void* value{};
-        check_hresult(WINRT_IMPL_SHIM(winrt::Windows::Web::AtomPub::IWorkspace)->get_Title(&value));
+        if constexpr (!std::is_same_v<D, winrt::Windows::Web::AtomPub::IWorkspace>)
+        {
+            winrt::hresult _winrt_cast_result_code;
+            auto const _winrt_casted_result = impl::try_as_with_reason<winrt::Windows::Web::AtomPub::IWorkspace, D const*>(static_cast<D const*>(this), _winrt_cast_result_code);
+            check_hresult(_winrt_cast_result_code);
+            auto const _winrt_abi_type = *(abi_t<winrt::Windows::Web::AtomPub::IWorkspace>**)&_winrt_casted_result;
+            check_hresult(_winrt_abi_type->get_Title(&value));
+        }
+        else
+        {
+            auto const _winrt_abi_type = *(abi_t<winrt::Windows::Web::AtomPub::IWorkspace>**)this;
+            check_hresult(_winrt_abi_type->get_Title(&value));
+        }
         return winrt::Windows::Web::Syndication::ISyndicationText{ value, take_ownership_from_abi };
     }
     template <typename D> auto consume_Windows_Web_AtomPub_IWorkspace<D>::Collections() const
     {
         void* value{};
-        check_hresult(WINRT_IMPL_SHIM(winrt::Windows::Web::AtomPub::IWorkspace)->get_Collections(&value));
+        if constexpr (!std::is_same_v<D, winrt::Windows::Web::AtomPub::IWorkspace>)
+        {
+            winrt::hresult _winrt_cast_result_code;
+            auto const _winrt_casted_result = impl::try_as_with_reason<winrt::Windows::Web::AtomPub::IWorkspace, D const*>(static_cast<D const*>(this), _winrt_cast_result_code);
+            check_hresult(_winrt_cast_result_code);
+            auto const _winrt_abi_type = *(abi_t<winrt::Windows::Web::AtomPub::IWorkspace>**)&_winrt_casted_result;
+            check_hresult(_winrt_abi_type->get_Collections(&value));
+        }
+        else
+        {
+            auto const _winrt_abi_type = *(abi_t<winrt::Windows::Web::AtomPub::IWorkspace>**)this;
+            check_hresult(_winrt_abi_type->get_Collections(&value));
+        }
         return winrt::Windows::Foundation::Collections::IVectorView<winrt::Windows::Web::AtomPub::ResourceCollection>{ value, take_ownership_from_abi };
     }
 #ifndef WINRT_LEAN_AND_MEAN
