@@ -1,4 +1,4 @@
-// C++/WinRT v2.0.240111.5
+// C++/WinRT v2.0.250303.1
 
 // SPDX-License-Identifier: MIT OR Apache-2.0
 // SPDX-FileCopyrightText: Copyright (c) Microsoft Corporation
@@ -71,6 +71,16 @@ WINRT_EXPORT namespace winrt::Windows::Devices::Enumeration
         AssociationEndpointContainer = 6,
         AssociationEndpointService = 7,
         DevicePanel = 8,
+        AssociationEndpointProtocol = 9,
+    };
+    enum class DevicePairingAddPairingSetMemberStatus : int32_t
+    {
+        AddedToSet = 0,
+        CouldNotBeAddedToSet = 1,
+        SetDiscoveryNotAttemptedByProtocol = 2,
+        SetDiscoveryCompletedByProtocol = 3,
+        SetDiscoveryPartiallyCompletedByProtocol = 4,
+        Failed = 5,
     };
     enum class DevicePairingKinds : uint32_t
     {
@@ -80,6 +90,7 @@ WINRT_EXPORT namespace winrt::Windows::Devices::Enumeration
         ProvidePin = 0x4,
         ConfirmPinMatch = 0x8,
         ProvidePasswordCredential = 0x10,
+        ProvideAddress = 0x20,
     };
     enum class DevicePairingProtectionLevel : int32_t
     {
@@ -153,24 +164,31 @@ WINRT_EXPORT namespace winrt::Windows::Devices::Enumeration
     };
     struct IDeviceAccessChangedEventArgs;
     struct IDeviceAccessChangedEventArgs2;
+    struct IDeviceAccessChangedEventArgs3;
     struct IDeviceAccessInformation;
+    struct IDeviceAccessInformation2;
     struct IDeviceAccessInformationStatics;
     struct IDeviceConnectionChangeTriggerDetails;
     struct IDeviceDisconnectButtonClickedEventArgs;
+    struct IDeviceEnumerationSettings;
     struct IDeviceInformation;
     struct IDeviceInformation2;
     struct IDeviceInformationCustomPairing;
+    struct IDeviceInformationCustomPairing2;
     struct IDeviceInformationPairing;
     struct IDeviceInformationPairing2;
     struct IDeviceInformationPairingStatics;
     struct IDeviceInformationPairingStatics2;
     struct IDeviceInformationStatics;
     struct IDeviceInformationStatics2;
+    struct IDeviceInformationStatics3;
     struct IDeviceInformationUpdate;
     struct IDeviceInformationUpdate2;
     struct IDevicePairingRequestedEventArgs;
     struct IDevicePairingRequestedEventArgs2;
+    struct IDevicePairingRequestedEventArgs3;
     struct IDevicePairingResult;
+    struct IDevicePairingSetMembersRequestedEventArgs;
     struct IDevicePairingSettings;
     struct IDevicePicker;
     struct IDevicePickerAppearance;
@@ -194,6 +212,7 @@ WINRT_EXPORT namespace winrt::Windows::Devices::Enumeration
     struct DeviceInformationUpdate;
     struct DevicePairingRequestedEventArgs;
     struct DevicePairingResult;
+    struct DevicePairingSetMembersRequestedEventArgs;
     struct DevicePicker;
     struct DevicePickerAppearance;
     struct DevicePickerFilter;
@@ -209,24 +228,31 @@ namespace winrt::impl
 {
     template <> struct category<winrt::Windows::Devices::Enumeration::IDeviceAccessChangedEventArgs>{ using type = interface_category; };
     template <> struct category<winrt::Windows::Devices::Enumeration::IDeviceAccessChangedEventArgs2>{ using type = interface_category; };
+    template <> struct category<winrt::Windows::Devices::Enumeration::IDeviceAccessChangedEventArgs3>{ using type = interface_category; };
     template <> struct category<winrt::Windows::Devices::Enumeration::IDeviceAccessInformation>{ using type = interface_category; };
+    template <> struct category<winrt::Windows::Devices::Enumeration::IDeviceAccessInformation2>{ using type = interface_category; };
     template <> struct category<winrt::Windows::Devices::Enumeration::IDeviceAccessInformationStatics>{ using type = interface_category; };
     template <> struct category<winrt::Windows::Devices::Enumeration::IDeviceConnectionChangeTriggerDetails>{ using type = interface_category; };
     template <> struct category<winrt::Windows::Devices::Enumeration::IDeviceDisconnectButtonClickedEventArgs>{ using type = interface_category; };
+    template <> struct category<winrt::Windows::Devices::Enumeration::IDeviceEnumerationSettings>{ using type = interface_category; };
     template <> struct category<winrt::Windows::Devices::Enumeration::IDeviceInformation>{ using type = interface_category; };
     template <> struct category<winrt::Windows::Devices::Enumeration::IDeviceInformation2>{ using type = interface_category; };
     template <> struct category<winrt::Windows::Devices::Enumeration::IDeviceInformationCustomPairing>{ using type = interface_category; };
+    template <> struct category<winrt::Windows::Devices::Enumeration::IDeviceInformationCustomPairing2>{ using type = interface_category; };
     template <> struct category<winrt::Windows::Devices::Enumeration::IDeviceInformationPairing>{ using type = interface_category; };
     template <> struct category<winrt::Windows::Devices::Enumeration::IDeviceInformationPairing2>{ using type = interface_category; };
     template <> struct category<winrt::Windows::Devices::Enumeration::IDeviceInformationPairingStatics>{ using type = interface_category; };
     template <> struct category<winrt::Windows::Devices::Enumeration::IDeviceInformationPairingStatics2>{ using type = interface_category; };
     template <> struct category<winrt::Windows::Devices::Enumeration::IDeviceInformationStatics>{ using type = interface_category; };
     template <> struct category<winrt::Windows::Devices::Enumeration::IDeviceInformationStatics2>{ using type = interface_category; };
+    template <> struct category<winrt::Windows::Devices::Enumeration::IDeviceInformationStatics3>{ using type = interface_category; };
     template <> struct category<winrt::Windows::Devices::Enumeration::IDeviceInformationUpdate>{ using type = interface_category; };
     template <> struct category<winrt::Windows::Devices::Enumeration::IDeviceInformationUpdate2>{ using type = interface_category; };
     template <> struct category<winrt::Windows::Devices::Enumeration::IDevicePairingRequestedEventArgs>{ using type = interface_category; };
     template <> struct category<winrt::Windows::Devices::Enumeration::IDevicePairingRequestedEventArgs2>{ using type = interface_category; };
+    template <> struct category<winrt::Windows::Devices::Enumeration::IDevicePairingRequestedEventArgs3>{ using type = interface_category; };
     template <> struct category<winrt::Windows::Devices::Enumeration::IDevicePairingResult>{ using type = interface_category; };
+    template <> struct category<winrt::Windows::Devices::Enumeration::IDevicePairingSetMembersRequestedEventArgs>{ using type = interface_category; };
     template <> struct category<winrt::Windows::Devices::Enumeration::IDevicePairingSettings>{ using type = interface_category; };
     template <> struct category<winrt::Windows::Devices::Enumeration::IDevicePicker>{ using type = interface_category; };
     template <> struct category<winrt::Windows::Devices::Enumeration::IDevicePickerAppearance>{ using type = interface_category; };
@@ -250,6 +276,7 @@ namespace winrt::impl
     template <> struct category<winrt::Windows::Devices::Enumeration::DeviceInformationUpdate>{ using type = class_category; };
     template <> struct category<winrt::Windows::Devices::Enumeration::DevicePairingRequestedEventArgs>{ using type = class_category; };
     template <> struct category<winrt::Windows::Devices::Enumeration::DevicePairingResult>{ using type = class_category; };
+    template <> struct category<winrt::Windows::Devices::Enumeration::DevicePairingSetMembersRequestedEventArgs>{ using type = class_category; };
     template <> struct category<winrt::Windows::Devices::Enumeration::DevicePicker>{ using type = class_category; };
     template <> struct category<winrt::Windows::Devices::Enumeration::DevicePickerAppearance>{ using type = class_category; };
     template <> struct category<winrt::Windows::Devices::Enumeration::DevicePickerFilter>{ using type = class_category; };
@@ -263,6 +290,7 @@ namespace winrt::impl
     template <> struct category<winrt::Windows::Devices::Enumeration::DeviceAccessStatus>{ using type = enum_category; };
     template <> struct category<winrt::Windows::Devices::Enumeration::DeviceClass>{ using type = enum_category; };
     template <> struct category<winrt::Windows::Devices::Enumeration::DeviceInformationKind>{ using type = enum_category; };
+    template <> struct category<winrt::Windows::Devices::Enumeration::DevicePairingAddPairingSetMemberStatus>{ using type = enum_category; };
     template <> struct category<winrt::Windows::Devices::Enumeration::DevicePairingKinds>{ using type = enum_category; };
     template <> struct category<winrt::Windows::Devices::Enumeration::DevicePairingProtectionLevel>{ using type = enum_category; };
     template <> struct category<winrt::Windows::Devices::Enumeration::DevicePairingResultStatus>{ using type = enum_category; };
@@ -282,6 +310,7 @@ namespace winrt::impl
     template <> inline constexpr auto& name_v<winrt::Windows::Devices::Enumeration::DeviceInformationUpdate> = L"Windows.Devices.Enumeration.DeviceInformationUpdate";
     template <> inline constexpr auto& name_v<winrt::Windows::Devices::Enumeration::DevicePairingRequestedEventArgs> = L"Windows.Devices.Enumeration.DevicePairingRequestedEventArgs";
     template <> inline constexpr auto& name_v<winrt::Windows::Devices::Enumeration::DevicePairingResult> = L"Windows.Devices.Enumeration.DevicePairingResult";
+    template <> inline constexpr auto& name_v<winrt::Windows::Devices::Enumeration::DevicePairingSetMembersRequestedEventArgs> = L"Windows.Devices.Enumeration.DevicePairingSetMembersRequestedEventArgs";
     template <> inline constexpr auto& name_v<winrt::Windows::Devices::Enumeration::DevicePicker> = L"Windows.Devices.Enumeration.DevicePicker";
     template <> inline constexpr auto& name_v<winrt::Windows::Devices::Enumeration::DevicePickerAppearance> = L"Windows.Devices.Enumeration.DevicePickerAppearance";
     template <> inline constexpr auto& name_v<winrt::Windows::Devices::Enumeration::DevicePickerFilter> = L"Windows.Devices.Enumeration.DevicePickerFilter";
@@ -295,6 +324,7 @@ namespace winrt::impl
     template <> inline constexpr auto& name_v<winrt::Windows::Devices::Enumeration::DeviceAccessStatus> = L"Windows.Devices.Enumeration.DeviceAccessStatus";
     template <> inline constexpr auto& name_v<winrt::Windows::Devices::Enumeration::DeviceClass> = L"Windows.Devices.Enumeration.DeviceClass";
     template <> inline constexpr auto& name_v<winrt::Windows::Devices::Enumeration::DeviceInformationKind> = L"Windows.Devices.Enumeration.DeviceInformationKind";
+    template <> inline constexpr auto& name_v<winrt::Windows::Devices::Enumeration::DevicePairingAddPairingSetMemberStatus> = L"Windows.Devices.Enumeration.DevicePairingAddPairingSetMemberStatus";
     template <> inline constexpr auto& name_v<winrt::Windows::Devices::Enumeration::DevicePairingKinds> = L"Windows.Devices.Enumeration.DevicePairingKinds";
     template <> inline constexpr auto& name_v<winrt::Windows::Devices::Enumeration::DevicePairingProtectionLevel> = L"Windows.Devices.Enumeration.DevicePairingProtectionLevel";
     template <> inline constexpr auto& name_v<winrt::Windows::Devices::Enumeration::DevicePairingResultStatus> = L"Windows.Devices.Enumeration.DevicePairingResultStatus";
@@ -305,24 +335,31 @@ namespace winrt::impl
     template <> inline constexpr auto& name_v<winrt::Windows::Devices::Enumeration::Panel> = L"Windows.Devices.Enumeration.Panel";
     template <> inline constexpr auto& name_v<winrt::Windows::Devices::Enumeration::IDeviceAccessChangedEventArgs> = L"Windows.Devices.Enumeration.IDeviceAccessChangedEventArgs";
     template <> inline constexpr auto& name_v<winrt::Windows::Devices::Enumeration::IDeviceAccessChangedEventArgs2> = L"Windows.Devices.Enumeration.IDeviceAccessChangedEventArgs2";
+    template <> inline constexpr auto& name_v<winrt::Windows::Devices::Enumeration::IDeviceAccessChangedEventArgs3> = L"Windows.Devices.Enumeration.IDeviceAccessChangedEventArgs3";
     template <> inline constexpr auto& name_v<winrt::Windows::Devices::Enumeration::IDeviceAccessInformation> = L"Windows.Devices.Enumeration.IDeviceAccessInformation";
+    template <> inline constexpr auto& name_v<winrt::Windows::Devices::Enumeration::IDeviceAccessInformation2> = L"Windows.Devices.Enumeration.IDeviceAccessInformation2";
     template <> inline constexpr auto& name_v<winrt::Windows::Devices::Enumeration::IDeviceAccessInformationStatics> = L"Windows.Devices.Enumeration.IDeviceAccessInformationStatics";
     template <> inline constexpr auto& name_v<winrt::Windows::Devices::Enumeration::IDeviceConnectionChangeTriggerDetails> = L"Windows.Devices.Enumeration.IDeviceConnectionChangeTriggerDetails";
     template <> inline constexpr auto& name_v<winrt::Windows::Devices::Enumeration::IDeviceDisconnectButtonClickedEventArgs> = L"Windows.Devices.Enumeration.IDeviceDisconnectButtonClickedEventArgs";
+    template <> inline constexpr auto& name_v<winrt::Windows::Devices::Enumeration::IDeviceEnumerationSettings> = L"Windows.Devices.Enumeration.IDeviceEnumerationSettings";
     template <> inline constexpr auto& name_v<winrt::Windows::Devices::Enumeration::IDeviceInformation> = L"Windows.Devices.Enumeration.IDeviceInformation";
     template <> inline constexpr auto& name_v<winrt::Windows::Devices::Enumeration::IDeviceInformation2> = L"Windows.Devices.Enumeration.IDeviceInformation2";
     template <> inline constexpr auto& name_v<winrt::Windows::Devices::Enumeration::IDeviceInformationCustomPairing> = L"Windows.Devices.Enumeration.IDeviceInformationCustomPairing";
+    template <> inline constexpr auto& name_v<winrt::Windows::Devices::Enumeration::IDeviceInformationCustomPairing2> = L"Windows.Devices.Enumeration.IDeviceInformationCustomPairing2";
     template <> inline constexpr auto& name_v<winrt::Windows::Devices::Enumeration::IDeviceInformationPairing> = L"Windows.Devices.Enumeration.IDeviceInformationPairing";
     template <> inline constexpr auto& name_v<winrt::Windows::Devices::Enumeration::IDeviceInformationPairing2> = L"Windows.Devices.Enumeration.IDeviceInformationPairing2";
     template <> inline constexpr auto& name_v<winrt::Windows::Devices::Enumeration::IDeviceInformationPairingStatics> = L"Windows.Devices.Enumeration.IDeviceInformationPairingStatics";
     template <> inline constexpr auto& name_v<winrt::Windows::Devices::Enumeration::IDeviceInformationPairingStatics2> = L"Windows.Devices.Enumeration.IDeviceInformationPairingStatics2";
     template <> inline constexpr auto& name_v<winrt::Windows::Devices::Enumeration::IDeviceInformationStatics> = L"Windows.Devices.Enumeration.IDeviceInformationStatics";
     template <> inline constexpr auto& name_v<winrt::Windows::Devices::Enumeration::IDeviceInformationStatics2> = L"Windows.Devices.Enumeration.IDeviceInformationStatics2";
+    template <> inline constexpr auto& name_v<winrt::Windows::Devices::Enumeration::IDeviceInformationStatics3> = L"Windows.Devices.Enumeration.IDeviceInformationStatics3";
     template <> inline constexpr auto& name_v<winrt::Windows::Devices::Enumeration::IDeviceInformationUpdate> = L"Windows.Devices.Enumeration.IDeviceInformationUpdate";
     template <> inline constexpr auto& name_v<winrt::Windows::Devices::Enumeration::IDeviceInformationUpdate2> = L"Windows.Devices.Enumeration.IDeviceInformationUpdate2";
     template <> inline constexpr auto& name_v<winrt::Windows::Devices::Enumeration::IDevicePairingRequestedEventArgs> = L"Windows.Devices.Enumeration.IDevicePairingRequestedEventArgs";
     template <> inline constexpr auto& name_v<winrt::Windows::Devices::Enumeration::IDevicePairingRequestedEventArgs2> = L"Windows.Devices.Enumeration.IDevicePairingRequestedEventArgs2";
+    template <> inline constexpr auto& name_v<winrt::Windows::Devices::Enumeration::IDevicePairingRequestedEventArgs3> = L"Windows.Devices.Enumeration.IDevicePairingRequestedEventArgs3";
     template <> inline constexpr auto& name_v<winrt::Windows::Devices::Enumeration::IDevicePairingResult> = L"Windows.Devices.Enumeration.IDevicePairingResult";
+    template <> inline constexpr auto& name_v<winrt::Windows::Devices::Enumeration::IDevicePairingSetMembersRequestedEventArgs> = L"Windows.Devices.Enumeration.IDevicePairingSetMembersRequestedEventArgs";
     template <> inline constexpr auto& name_v<winrt::Windows::Devices::Enumeration::IDevicePairingSettings> = L"Windows.Devices.Enumeration.IDevicePairingSettings";
     template <> inline constexpr auto& name_v<winrt::Windows::Devices::Enumeration::IDevicePicker> = L"Windows.Devices.Enumeration.IDevicePicker";
     template <> inline constexpr auto& name_v<winrt::Windows::Devices::Enumeration::IDevicePickerAppearance> = L"Windows.Devices.Enumeration.IDevicePickerAppearance";
@@ -337,24 +374,31 @@ namespace winrt::impl
     template <> inline constexpr auto& name_v<winrt::Windows::Devices::Enumeration::IEnclosureLocation2> = L"Windows.Devices.Enumeration.IEnclosureLocation2";
     template <> inline constexpr guid guid_v<winrt::Windows::Devices::Enumeration::IDeviceAccessChangedEventArgs>{ 0xDEDA0BCC,0x4F9D,0x4F58,{ 0x9D,0xBA,0xA9,0xBC,0x80,0x04,0x08,0xD5 } }; // DEDA0BCC-4F9D-4F58-9DBA-A9BC800408D5
     template <> inline constexpr guid guid_v<winrt::Windows::Devices::Enumeration::IDeviceAccessChangedEventArgs2>{ 0x82523262,0x934B,0x4B30,{ 0xA1,0x78,0xAD,0xC3,0x9F,0x2F,0x2B,0xE3 } }; // 82523262-934B-4B30-A178-ADC39F2F2BE3
+    template <> inline constexpr guid guid_v<winrt::Windows::Devices::Enumeration::IDeviceAccessChangedEventArgs3>{ 0x7580A878,0x7FD9,0x5CD7,{ 0x85,0x60,0x3C,0x64,0x4B,0x9B,0x10,0xDB } }; // 7580A878-7FD9-5CD7-8560-3C644B9B10DB
     template <> inline constexpr guid guid_v<winrt::Windows::Devices::Enumeration::IDeviceAccessInformation>{ 0x0BAA9A73,0x6DE5,0x4915,{ 0x8D,0xDD,0x9A,0x05,0x54,0xA6,0xF5,0x45 } }; // 0BAA9A73-6DE5-4915-8DDD-9A0554A6F545
+    template <> inline constexpr guid guid_v<winrt::Windows::Devices::Enumeration::IDeviceAccessInformation2>{ 0xE2B9DFF6,0xE88F,0x5D0A,{ 0x9C,0x1E,0xD7,0x88,0x80,0x8D,0xF4,0x7B } }; // E2B9DFF6-E88F-5D0A-9C1E-D788808DF47B
     template <> inline constexpr guid guid_v<winrt::Windows::Devices::Enumeration::IDeviceAccessInformationStatics>{ 0x574BD3D3,0x5F30,0x45CD,{ 0x8A,0x94,0x72,0x4F,0xE5,0x97,0x30,0x84 } }; // 574BD3D3-5F30-45CD-8A94-724FE5973084
     template <> inline constexpr guid guid_v<winrt::Windows::Devices::Enumeration::IDeviceConnectionChangeTriggerDetails>{ 0xB8578C0C,0xBBC1,0x484B,{ 0xBF,0xFA,0x7B,0x31,0xDC,0xC2,0x00,0xB2 } }; // B8578C0C-BBC1-484B-BFFA-7B31DCC200B2
     template <> inline constexpr guid guid_v<winrt::Windows::Devices::Enumeration::IDeviceDisconnectButtonClickedEventArgs>{ 0x8E44B56D,0xF902,0x4A00,{ 0xB5,0x36,0xF3,0x79,0x92,0xE6,0xA2,0xA7 } }; // 8E44B56D-F902-4A00-B536-F37992E6A2A7
+    template <> inline constexpr guid guid_v<winrt::Windows::Devices::Enumeration::IDeviceEnumerationSettings>{ 0xF7710F66,0x9FF3,0x41C8,{ 0x85,0xEB,0x87,0xF8,0x11,0x48,0xA3,0x0F } }; // F7710F66-9FF3-41C8-85EB-87F81148A30F
     template <> inline constexpr guid guid_v<winrt::Windows::Devices::Enumeration::IDeviceInformation>{ 0xABA0FB95,0x4398,0x489D,{ 0x8E,0x44,0xE6,0x13,0x09,0x27,0x01,0x1F } }; // ABA0FB95-4398-489D-8E44-E6130927011F
     template <> inline constexpr guid guid_v<winrt::Windows::Devices::Enumeration::IDeviceInformation2>{ 0xF156A638,0x7997,0x48D9,{ 0xA1,0x0C,0x26,0x9D,0x46,0x53,0x3F,0x48 } }; // F156A638-7997-48D9-A10C-269D46533F48
     template <> inline constexpr guid guid_v<winrt::Windows::Devices::Enumeration::IDeviceInformationCustomPairing>{ 0x85138C02,0x4EE6,0x4914,{ 0x83,0x70,0x10,0x7A,0x39,0x14,0x4C,0x0E } }; // 85138C02-4EE6-4914-8370-107A39144C0E
+    template <> inline constexpr guid guid_v<winrt::Windows::Devices::Enumeration::IDeviceInformationCustomPairing2>{ 0x0EBDA662,0xE696,0x5FA9,{ 0x8F,0x72,0x80,0xCF,0xEB,0xCD,0x85,0x1D } }; // 0EBDA662-E696-5FA9-8F72-80CFEBCD851D
     template <> inline constexpr guid guid_v<winrt::Windows::Devices::Enumeration::IDeviceInformationPairing>{ 0x2C4769F5,0xF684,0x40D5,{ 0x84,0x69,0xE8,0xDB,0xAA,0xB7,0x04,0x85 } }; // 2C4769F5-F684-40D5-8469-E8DBAAB70485
     template <> inline constexpr guid guid_v<winrt::Windows::Devices::Enumeration::IDeviceInformationPairing2>{ 0xF68612FD,0x0AEE,0x4328,{ 0x85,0xCC,0x1C,0x74,0x2B,0xB1,0x79,0x0D } }; // F68612FD-0AEE-4328-85CC-1C742BB1790D
     template <> inline constexpr guid guid_v<winrt::Windows::Devices::Enumeration::IDeviceInformationPairingStatics>{ 0xE915C408,0x36D4,0x49A1,{ 0xBF,0x13,0x51,0x41,0x73,0x79,0x9B,0x6B } }; // E915C408-36D4-49A1-BF13-514173799B6B
     template <> inline constexpr guid guid_v<winrt::Windows::Devices::Enumeration::IDeviceInformationPairingStatics2>{ 0x04DE5372,0xB7B7,0x476B,{ 0xA7,0x4F,0xC5,0x83,0x6A,0x70,0x4D,0x98 } }; // 04DE5372-B7B7-476B-A74F-C5836A704D98
     template <> inline constexpr guid guid_v<winrt::Windows::Devices::Enumeration::IDeviceInformationStatics>{ 0xC17F100E,0x3A46,0x4A78,{ 0x80,0x13,0x76,0x9D,0xC9,0xB9,0x73,0x90 } }; // C17F100E-3A46-4A78-8013-769DC9B97390
     template <> inline constexpr guid guid_v<winrt::Windows::Devices::Enumeration::IDeviceInformationStatics2>{ 0x493B4F34,0xA84F,0x45FD,{ 0x91,0x67,0x15,0xD1,0xCB,0x1B,0xD1,0xF9 } }; // 493B4F34-A84F-45FD-9167-15D1CB1BD1F9
+    template <> inline constexpr guid guid_v<winrt::Windows::Devices::Enumeration::IDeviceInformationStatics3>{ 0x25F06279,0x9364,0x5A6C,{ 0x8A,0x54,0x5D,0x4A,0x6D,0x3D,0x92,0x2A } }; // 25F06279-9364-5A6C-8A54-5D4A6D3D922A
     template <> inline constexpr guid guid_v<winrt::Windows::Devices::Enumeration::IDeviceInformationUpdate>{ 0x8F315305,0xD972,0x44B7,{ 0xA3,0x7E,0x9E,0x82,0x2C,0x78,0x21,0x3B } }; // 8F315305-D972-44B7-A37E-9E822C78213B
     template <> inline constexpr guid guid_v<winrt::Windows::Devices::Enumeration::IDeviceInformationUpdate2>{ 0x5D9D148C,0xA873,0x485E,{ 0xBA,0xA6,0xAA,0x62,0x07,0x88,0xE3,0xCC } }; // 5D9D148C-A873-485E-BAA6-AA620788E3CC
     template <> inline constexpr guid guid_v<winrt::Windows::Devices::Enumeration::IDevicePairingRequestedEventArgs>{ 0xF717FC56,0xDE6B,0x487F,{ 0x83,0x76,0x01,0x80,0xAC,0xA6,0x99,0x63 } }; // F717FC56-DE6B-487F-8376-0180ACA69963
     template <> inline constexpr guid guid_v<winrt::Windows::Devices::Enumeration::IDevicePairingRequestedEventArgs2>{ 0xC83752D9,0xE4D3,0x4DB0,{ 0xA3,0x60,0xA1,0x05,0xE4,0x37,0xDB,0xDC } }; // C83752D9-E4D3-4DB0-A360-A105E437DBDC
+    template <> inline constexpr guid guid_v<winrt::Windows::Devices::Enumeration::IDevicePairingRequestedEventArgs3>{ 0x195E5A38,0x43DC,0x562F,{ 0xBA,0xBE,0xEF,0xC8,0xB1,0x10,0x08,0x8B } }; // 195E5A38-43DC-562F-BABE-EFC8B110088B
     template <> inline constexpr guid guid_v<winrt::Windows::Devices::Enumeration::IDevicePairingResult>{ 0x072B02BF,0xDD95,0x4025,{ 0x9B,0x37,0xDE,0x51,0xAD,0xBA,0x37,0xB7 } }; // 072B02BF-DD95-4025-9B37-DE51ADBA37B7
+    template <> inline constexpr guid guid_v<winrt::Windows::Devices::Enumeration::IDevicePairingSetMembersRequestedEventArgs>{ 0x7FB42CFF,0xECAC,0x5012,{ 0x8D,0x7D,0xA1,0x89,0x46,0x80,0xA3,0x49 } }; // 7FB42CFF-ECAC-5012-8D7D-A1894680A349
     template <> inline constexpr guid guid_v<winrt::Windows::Devices::Enumeration::IDevicePairingSettings>{ 0x482CB27C,0x83BB,0x420E,{ 0xBE,0x51,0x66,0x02,0xB2,0x22,0xDE,0x54 } }; // 482CB27C-83BB-420E-BE51-6602B222DE54
     template <> inline constexpr guid guid_v<winrt::Windows::Devices::Enumeration::IDevicePicker>{ 0x84997AA2,0x034A,0x4440,{ 0x88,0x13,0x7D,0x0B,0xD4,0x79,0xBF,0x5A } }; // 84997AA2-034A-4440-8813-7D0BD479BF5A
     template <> inline constexpr guid guid_v<winrt::Windows::Devices::Enumeration::IDevicePickerAppearance>{ 0xE69A12C6,0xE627,0x4ED8,{ 0x9B,0x6C,0x46,0x0A,0xF4,0x45,0xE5,0x6D } }; // E69A12C6-E627-4ED8-9B6C-460AF445E56D
@@ -378,6 +422,7 @@ namespace winrt::impl
     template <> struct default_interface<winrt::Windows::Devices::Enumeration::DeviceInformationUpdate>{ using type = winrt::Windows::Devices::Enumeration::IDeviceInformationUpdate; };
     template <> struct default_interface<winrt::Windows::Devices::Enumeration::DevicePairingRequestedEventArgs>{ using type = winrt::Windows::Devices::Enumeration::IDevicePairingRequestedEventArgs; };
     template <> struct default_interface<winrt::Windows::Devices::Enumeration::DevicePairingResult>{ using type = winrt::Windows::Devices::Enumeration::IDevicePairingResult; };
+    template <> struct default_interface<winrt::Windows::Devices::Enumeration::DevicePairingSetMembersRequestedEventArgs>{ using type = winrt::Windows::Devices::Enumeration::IDevicePairingSetMembersRequestedEventArgs; };
     template <> struct default_interface<winrt::Windows::Devices::Enumeration::DevicePicker>{ using type = winrt::Windows::Devices::Enumeration::IDevicePicker; };
     template <> struct default_interface<winrt::Windows::Devices::Enumeration::DevicePickerAppearance>{ using type = winrt::Windows::Devices::Enumeration::IDevicePickerAppearance; };
     template <> struct default_interface<winrt::Windows::Devices::Enumeration::DevicePickerFilter>{ using type = winrt::Windows::Devices::Enumeration::IDevicePickerFilter; };
@@ -402,6 +447,13 @@ namespace winrt::impl
             virtual int32_t __stdcall get_Id(void**) noexcept = 0;
         };
     };
+    template <> struct abi<winrt::Windows::Devices::Enumeration::IDeviceAccessChangedEventArgs3>
+    {
+        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
+        {
+            virtual int32_t __stdcall get_UserPromptRequired(bool*) noexcept = 0;
+        };
+    };
     template <> struct abi<winrt::Windows::Devices::Enumeration::IDeviceAccessInformation>
     {
         struct WINRT_IMPL_NOVTABLE type : inspectable_abi
@@ -411,6 +463,13 @@ namespace winrt::impl
             virtual int32_t __stdcall get_CurrentStatus(int32_t*) noexcept = 0;
         };
     };
+    template <> struct abi<winrt::Windows::Devices::Enumeration::IDeviceAccessInformation2>
+    {
+        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
+        {
+            virtual int32_t __stdcall get_UserPromptRequired(bool*) noexcept = 0;
+        };
+    };
     template <> struct abi<winrt::Windows::Devices::Enumeration::IDeviceAccessInformationStatics>
     {
         struct WINRT_IMPL_NOVTABLE type : inspectable_abi
@@ -434,6 +493,12 @@ namespace winrt::impl
             virtual int32_t __stdcall get_Device(void**) noexcept = 0;
         };
     };
+    template <> struct abi<winrt::Windows::Devices::Enumeration::IDeviceEnumerationSettings>
+    {
+        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
+        {
+        };
+    };
     template <> struct abi<winrt::Windows::Devices::Enumeration::IDeviceInformation>
     {
         struct WINRT_IMPL_NOVTABLE type : inspectable_abi
@@ -468,6 +533,15 @@ namespace winrt::impl
             virtual int32_t __stdcall remove_PairingRequested(winrt::event_token) noexcept = 0;
         };
     };
+    template <> struct abi<winrt::Windows::Devices::Enumeration::IDeviceInformationCustomPairing2>
+    {
+        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
+        {
+            virtual int32_t __stdcall AddPairingSetMember(void*) noexcept = 0;
+            virtual int32_t __stdcall add_PairingSetMembersRequested(void*, winrt::event_token*) noexcept = 0;
+            virtual int32_t __stdcall remove_PairingSetMembersRequested(winrt::event_token) noexcept = 0;
+        };
+    };
     template <> struct abi<winrt::Windows::Devices::Enumeration::IDeviceInformationPairing>
     {
         struct WINRT_IMPL_NOVTABLE type : inspectable_abi
@@ -528,6 +602,15 @@ namespace winrt::impl
             virtual int32_t __stdcall CreateWatcherWithKindAqsFilterAndAdditionalProperties(void*, void*, int32_t, void**) noexcept = 0;
         };
     };
+    template <> struct abi<winrt::Windows::Devices::Enumeration::IDeviceInformationStatics3>
+    {
+        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
+        {
+            virtual int32_t __stdcall CreateFromIdAsyncWithAdditionalPropertiesKindAndSettings(void*, void*, int32_t, void*, void**) noexcept = 0;
+            virtual int32_t __stdcall FindAllAsyncWithAqsFilterAdditionalPropertiesKindAndSettings(void*, void*, int32_t, void*, void**) noexcept = 0;
+            virtual int32_t __stdcall CreateWatcherWithAqsFilterAdditionalPropertiesKindAndSettings(void*, void*, int32_t, void*, void**) noexcept = 0;
+        };
+    };
     template <> struct abi<winrt::Windows::Devices::Enumeration::IDeviceInformationUpdate>
     {
         struct WINRT_IMPL_NOVTABLE type : inspectable_abi
@@ -562,6 +645,13 @@ namespace winrt::impl
             virtual int32_t __stdcall AcceptWithPasswordCredential(void*) noexcept = 0;
         };
     };
+    template <> struct abi<winrt::Windows::Devices::Enumeration::IDevicePairingRequestedEventArgs3>
+    {
+        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
+        {
+            virtual int32_t __stdcall AcceptWithAddress(void*) noexcept = 0;
+        };
+    };
     template <> struct abi<winrt::Windows::Devices::Enumeration::IDevicePairingResult>
     {
         struct WINRT_IMPL_NOVTABLE type : inspectable_abi
@@ -570,6 +660,15 @@ namespace winrt::impl
             virtual int32_t __stdcall get_ProtectionLevelUsed(int32_t*) noexcept = 0;
         };
     };
+    template <> struct abi<winrt::Windows::Devices::Enumeration::IDevicePairingSetMembersRequestedEventArgs>
+    {
+        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
+        {
+            virtual int32_t __stdcall get_Status(int32_t*) noexcept = 0;
+            virtual int32_t __stdcall get_ParentDeviceInformation(void**) noexcept = 0;
+            virtual int32_t __stdcall get_PairingSetMembers(void**) noexcept = 0;
+        };
+    };
     template <> struct abi<winrt::Windows::Devices::Enumeration::IDevicePairingSettings>
     {
         struct WINRT_IMPL_NOVTABLE type : inspectable_abi
@@ -716,6 +815,15 @@ namespace winrt::impl
         template <typename D> using type = consume_Windows_Devices_Enumeration_IDeviceAccessChangedEventArgs2<D>;
     };
     template <typename D>
+    struct consume_Windows_Devices_Enumeration_IDeviceAccessChangedEventArgs3
+    {
+        [[nodiscard]] auto UserPromptRequired() const;
+    };
+    template <> struct consume<winrt::Windows::Devices::Enumeration::IDeviceAccessChangedEventArgs3>
+    {
+        template <typename D> using type = consume_Windows_Devices_Enumeration_IDeviceAccessChangedEventArgs3<D>;
+    };
+    template <typename D>
     struct consume_Windows_Devices_Enumeration_IDeviceAccessInformation
     {
         auto AccessChanged(winrt::Windows::Foundation::TypedEventHandler<winrt::Windows::Devices::Enumeration::DeviceAccessInformation, winrt::Windows::Devices::Enumeration::DeviceAccessChangedEventArgs> const& handler) const;
@@ -729,6 +837,15 @@ namespace winrt::impl
         template <typename D> using type = consume_Windows_Devices_Enumeration_IDeviceAccessInformation<D>;
     };
     template <typename D>
+    struct consume_Windows_Devices_Enumeration_IDeviceAccessInformation2
+    {
+        [[nodiscard]] auto UserPromptRequired() const;
+    };
+    template <> struct consume<winrt::Windows::Devices::Enumeration::IDeviceAccessInformation2>
+    {
+        template <typename D> using type = consume_Windows_Devices_Enumeration_IDeviceAccessInformation2<D>;
+    };
+    template <typename D>
     struct consume_Windows_Devices_Enumeration_IDeviceAccessInformationStatics
     {
         auto CreateFromId(param::hstring const& deviceId) const;
@@ -758,6 +875,14 @@ namespace winrt::impl
         template <typename D> using type = consume_Windows_Devices_Enumeration_IDeviceDisconnectButtonClickedEventArgs<D>;
     };
     template <typename D>
+    struct consume_Windows_Devices_Enumeration_IDeviceEnumerationSettings
+    {
+    };
+    template <> struct consume<winrt::Windows::Devices::Enumeration::IDeviceEnumerationSettings>
+    {
+        template <typename D> using type = consume_Windows_Devices_Enumeration_IDeviceEnumerationSettings<D>;
+    };
+    template <typename D>
     struct consume_Windows_Devices_Enumeration_IDeviceInformation
     {
         [[nodiscard]] auto Id() const;
@@ -800,6 +925,19 @@ namespace winrt::impl
         template <typename D> using type = consume_Windows_Devices_Enumeration_IDeviceInformationCustomPairing<D>;
     };
     template <typename D>
+    struct consume_Windows_Devices_Enumeration_IDeviceInformationCustomPairing2
+    {
+        auto AddPairingSetMember(winrt::Windows::Devices::Enumeration::DeviceInformation const& device) const;
+        auto PairingSetMembersRequested(winrt::Windows::Foundation::TypedEventHandler<winrt::Windows::Devices::Enumeration::DeviceInformationCustomPairing, winrt::Windows::Devices::Enumeration::DevicePairingSetMembersRequestedEventArgs> const& handler) const;
+        using PairingSetMembersRequested_revoker = impl::event_revoker<winrt::Windows::Devices::Enumeration::IDeviceInformationCustomPairing2, &impl::abi_t<winrt::Windows::Devices::Enumeration::IDeviceInformationCustomPairing2>::remove_PairingSetMembersRequested>;
+        [[nodiscard]] auto PairingSetMembersRequested(auto_revoke_t, winrt::Windows::Foundation::TypedEventHandler<winrt::Windows::Devices::Enumeration::DeviceInformationCustomPairing, winrt::Windows::Devices::Enumeration::DevicePairingSetMembersRequestedEventArgs> const& handler) const;
+        auto PairingSetMembersRequested(winrt::event_token const& token) const noexcept;
+    };
+    template <> struct consume<winrt::Windows::Devices::Enumeration::IDeviceInformationCustomPairing2>
+    {
+        template <typename D> using type = consume_Windows_Devices_Enumeration_IDeviceInformationCustomPairing2<D>;
+    };
+    template <typename D>
     struct consume_Windows_Devices_Enumeration_IDeviceInformationPairing
     {
         [[nodiscard]] auto IsPaired() const;
@@ -872,6 +1010,17 @@ namespace winrt::impl
         template <typename D> using type = consume_Windows_Devices_Enumeration_IDeviceInformationStatics2<D>;
     };
     template <typename D>
+    struct consume_Windows_Devices_Enumeration_IDeviceInformationStatics3
+    {
+        auto CreateFromIdAsync(param::hstring const& deviceId, param::async_iterable<hstring> const& additionalProperties, winrt::Windows::Devices::Enumeration::DeviceInformationKind const& kind, winrt::Windows::Devices::Enumeration::IDeviceEnumerationSettings const& settings) const;
+        auto FindAllAsync(param::hstring const& aqsFilter, param::async_iterable<hstring> const& additionalProperties, winrt::Windows::Devices::Enumeration::DeviceInformationKind const& kind, winrt::Windows::Devices::Enumeration::IDeviceEnumerationSettings const& settings) const;
+        auto CreateWatcher(param::hstring const& aqsFilter, param::iterable<hstring> const& additionalProperties, winrt::Windows::Devices::Enumeration::DeviceInformationKind const& kind, winrt::Windows::Devices::Enumeration::IDeviceEnumerationSettings const& settings) const;
+    };
+    template <> struct consume<winrt::Windows::Devices::Enumeration::IDeviceInformationStatics3>
+    {
+        template <typename D> using type = consume_Windows_Devices_Enumeration_IDeviceInformationStatics3<D>;
+    };
+    template <typename D>
     struct consume_Windows_Devices_Enumeration_IDeviceInformationUpdate
     {
         [[nodiscard]] auto Id() const;
@@ -914,6 +1063,15 @@ namespace winrt::impl
         template <typename D> using type = consume_Windows_Devices_Enumeration_IDevicePairingRequestedEventArgs2<D>;
     };
     template <typename D>
+    struct consume_Windows_Devices_Enumeration_IDevicePairingRequestedEventArgs3
+    {
+        auto AcceptWithAddress(param::hstring const& address) const;
+    };
+    template <> struct consume<winrt::Windows::Devices::Enumeration::IDevicePairingRequestedEventArgs3>
+    {
+        template <typename D> using type = consume_Windows_Devices_Enumeration_IDevicePairingRequestedEventArgs3<D>;
+    };
+    template <typename D>
     struct consume_Windows_Devices_Enumeration_IDevicePairingResult
     {
         [[nodiscard]] auto Status() const;
@@ -924,6 +1082,17 @@ namespace winrt::impl
         template <typename D> using type = consume_Windows_Devices_Enumeration_IDevicePairingResult<D>;
     };
     template <typename D>
+    struct consume_Windows_Devices_Enumeration_IDevicePairingSetMembersRequestedEventArgs
+    {
+        [[nodiscard]] auto Status() const;
+        [[nodiscard]] auto ParentDeviceInformation() const;
+        [[nodiscard]] auto PairingSetMembers() const;
+    };
+    template <> struct consume<winrt::Windows::Devices::Enumeration::IDevicePairingSetMembersRequestedEventArgs>
+    {
+        template <typename D> using type = consume_Windows_Devices_Enumeration_IDevicePairingSetMembersRequestedEventArgs<D>;
+    };
+    template <typename D>
     struct consume_Windows_Devices_Enumeration_IDevicePairingSettings
     {
     };
