@@ -1,4 +1,4 @@
-// C++/WinRT v2.0.240111.5
+// C++/WinRT v2.0.250303.1
 
 // SPDX-License-Identifier: MIT OR Apache-2.0
 // SPDX-FileCopyrightText: Copyright (c) Microsoft Corporation
@@ -69,6 +69,20 @@ WINRT_EXPORT namespace winrt::Windows::Graphics::Printing::Workflow
         IPrintWorkflowJobBackgroundSession(std::nullptr_t = nullptr) noexcept {}
         IPrintWorkflowJobBackgroundSession(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
     };
+    struct WINRT_IMPL_EMPTY_BASES IPrintWorkflowJobBackgroundSession2 :
+        winrt::Windows::Foundation::IInspectable,
+        impl::consume_t<IPrintWorkflowJobBackgroundSession2>
+    {
+        IPrintWorkflowJobBackgroundSession2(std::nullptr_t = nullptr) noexcept {}
+        IPrintWorkflowJobBackgroundSession2(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
+    };
+    struct WINRT_IMPL_EMPTY_BASES IPrintWorkflowJobIssueDetectedEventArgs :
+        winrt::Windows::Foundation::IInspectable,
+        impl::consume_t<IPrintWorkflowJobIssueDetectedEventArgs>
+    {
+        IPrintWorkflowJobIssueDetectedEventArgs(std::nullptr_t = nullptr) noexcept {}
+        IPrintWorkflowJobIssueDetectedEventArgs(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
+    };
     struct WINRT_IMPL_EMPTY_BASES IPrintWorkflowJobNotificationEventArgs :
         winrt::Windows::Foundation::IInspectable,
         impl::consume_t<IPrintWorkflowJobNotificationEventArgs>
@@ -83,6 +97,13 @@ WINRT_EXPORT namespace winrt::Windows::Graphics::Printing::Workflow
         IPrintWorkflowJobStartingEventArgs(std::nullptr_t = nullptr) noexcept {}
         IPrintWorkflowJobStartingEventArgs(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
     };
+    struct WINRT_IMPL_EMPTY_BASES IPrintWorkflowJobStartingEventArgs2 :
+        winrt::Windows::Foundation::IInspectable,
+        impl::consume_t<IPrintWorkflowJobStartingEventArgs2>
+    {
+        IPrintWorkflowJobStartingEventArgs2(std::nullptr_t = nullptr) noexcept {}
+        IPrintWorkflowJobStartingEventArgs2(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
+    };
     struct WINRT_IMPL_EMPTY_BASES IPrintWorkflowJobTriggerDetails :
         winrt::Windows::Foundation::IInspectable,
         impl::consume_t<IPrintWorkflowJobTriggerDetails>
@@ -97,6 +118,13 @@ WINRT_EXPORT namespace winrt::Windows::Graphics::Printing::Workflow
         IPrintWorkflowJobUISession(std::nullptr_t = nullptr) noexcept {}
         IPrintWorkflowJobUISession(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
     };
+    struct WINRT_IMPL_EMPTY_BASES IPrintWorkflowJobUISession2 :
+        winrt::Windows::Foundation::IInspectable,
+        impl::consume_t<IPrintWorkflowJobUISession2>
+    {
+        IPrintWorkflowJobUISession2(std::nullptr_t = nullptr) noexcept {}
+        IPrintWorkflowJobUISession2(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
+    };
     struct WINRT_IMPL_EMPTY_BASES IPrintWorkflowObjectModelSourceFileContent :
         winrt::Windows::Foundation::IInspectable,
         impl::consume_t<IPrintWorkflowObjectModelSourceFileContent>
@@ -174,6 +202,13 @@ WINRT_EXPORT namespace winrt::Windows::Graphics::Printing::Workflow
         IPrintWorkflowPrinterJob(std::nullptr_t = nullptr) noexcept {}
         IPrintWorkflowPrinterJob(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
     };
+    struct WINRT_IMPL_EMPTY_BASES IPrintWorkflowPrinterJob2 :
+        winrt::Windows::Foundation::IInspectable,
+        impl::consume_t<IPrintWorkflowPrinterJob2>
+    {
+        IPrintWorkflowPrinterJob2(std::nullptr_t = nullptr) noexcept {}
+        IPrintWorkflowPrinterJob2(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
+    };
     struct WINRT_IMPL_EMPTY_BASES IPrintWorkflowSourceContent :
         winrt::Windows::Foundation::IInspectable,
         impl::consume_t<IPrintWorkflowSourceContent>
@@ -238,6 +273,34 @@ WINRT_EXPORT namespace winrt::Windows::Graphics::Printing::Workflow
         IPrintWorkflowUILauncher(std::nullptr_t = nullptr) noexcept {}
         IPrintWorkflowUILauncher(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
     };
+    struct WINRT_IMPL_EMPTY_BASES IPrintWorkflowVirtualPrinterDataAvailableEventArgs :
+        winrt::Windows::Foundation::IInspectable,
+        impl::consume_t<IPrintWorkflowVirtualPrinterDataAvailableEventArgs>
+    {
+        IPrintWorkflowVirtualPrinterDataAvailableEventArgs(std::nullptr_t = nullptr) noexcept {}
+        IPrintWorkflowVirtualPrinterDataAvailableEventArgs(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
+    };
+    struct WINRT_IMPL_EMPTY_BASES IPrintWorkflowVirtualPrinterSession :
+        winrt::Windows::Foundation::IInspectable,
+        impl::consume_t<IPrintWorkflowVirtualPrinterSession>
+    {
+        IPrintWorkflowVirtualPrinterSession(std::nullptr_t = nullptr) noexcept {}
+        IPrintWorkflowVirtualPrinterSession(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
+    };
+    struct WINRT_IMPL_EMPTY_BASES IPrintWorkflowVirtualPrinterTriggerDetails :
+        winrt::Windows::Foundation::IInspectable,
+        impl::consume_t<IPrintWorkflowVirtualPrinterTriggerDetails>
+    {
+        IPrintWorkflowVirtualPrinterTriggerDetails(std::nullptr_t = nullptr) noexcept {}
+        IPrintWorkflowVirtualPrinterTriggerDetails(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
+    };
+    struct WINRT_IMPL_EMPTY_BASES IPrintWorkflowVirtualPrinterUIEventArgs :
+        winrt::Windows::Foundation::IInspectable,
+        impl::consume_t<IPrintWorkflowVirtualPrinterUIEventArgs>
+    {
+        IPrintWorkflowVirtualPrinterUIEventArgs(std::nullptr_t = nullptr) noexcept {}
+        IPrintWorkflowVirtualPrinterUIEventArgs(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
+    };
     struct WINRT_IMPL_EMPTY_BASES IPrintWorkflowXpsDataAvailableEventArgs :
         winrt::Windows::Foundation::IInspectable,
         impl::consume_t<IPrintWorkflowXpsDataAvailableEventArgs>
