@@ -1,4 +1,4 @@
-// C++/WinRT v2.0.240405.15
+// C++/WinRT v2.0.250303.1
 
 // SPDX-License-Identifier: MIT OR Apache-2.0
 // SPDX-FileCopyrightText: Copyright (c) Microsoft Corporation
@@ -43,9 +43,9 @@ WINRT_EXPORT namespace winrt::Windows::Media::Capture
     };
     struct WhiteBalanceGain
     {
-        double R;
-        double G;
-        double B;
+        double R {};
+        double G {};
+        double B {};
     };
     inline bool operator==(WhiteBalanceGain const& left, WhiteBalanceGain const& right) noexcept
     {
@@ -447,17 +447,6 @@ WINRT_EXPORT namespace winrt::Windows::Media::Capture
         PhotoConfirmationCapturedEventArgs(std::nullptr_t) noexcept {}
         PhotoConfirmationCapturedEventArgs(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Media::Capture::IPhotoConfirmationCapturedEventArgs(ptr, take_ownership_from_abi) {}
     };
-    struct WINRT_IMPL_EMPTY_BASES ScreenCapture : winrt::Windows::Media::Capture::IScreenCapture
-    {
-        ScreenCapture(std::nullptr_t) noexcept {}
-        ScreenCapture(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Media::Capture::IScreenCapture(ptr, take_ownership_from_abi) {}
-        static auto GetForCurrentView();
-    };
-    struct WINRT_IMPL_EMPTY_BASES SourceSuspensionChangedEventArgs : winrt::Windows::Media::Capture::ISourceSuspensionChangedEventArgs
-    {
-        SourceSuspensionChangedEventArgs(std::nullptr_t) noexcept {}
-        SourceSuspensionChangedEventArgs(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Media::Capture::ISourceSuspensionChangedEventArgs(ptr, take_ownership_from_abi) {}
-    };
     struct WINRT_IMPL_EMPTY_BASES VideoStreamConfiguration : winrt::Windows::Media::Capture::IVideoStreamConfiguration
     {
         VideoStreamConfiguration(std::nullptr_t) noexcept {}
