@@ -1,4 +1,4 @@
-// C++/WinRT v2.0.240111.5
+// C++/WinRT v2.0.250303.1
 
 // SPDX-License-Identifier: MIT OR Apache-2.0
 // SPDX-FileCopyrightText: Copyright (c) Microsoft Corporation
@@ -92,9 +92,11 @@ WINRT_EXPORT namespace winrt::Windows::Media::MediaProperties
     struct IAudioEncodingPropertiesStatics;
     struct IAudioEncodingPropertiesStatics2;
     struct IAudioEncodingPropertiesWithFormatUserData;
+    struct IAv1ProfileIdsStatics;
     struct IContainerEncodingProperties;
     struct IContainerEncodingProperties2;
     struct IH264ProfileIdsStatics;
+    struct IHevcProfileIdsStatics;
     struct IImageEncodingProperties;
     struct IImageEncodingProperties2;
     struct IImageEncodingPropertiesStatics;
@@ -106,6 +108,7 @@ WINRT_EXPORT namespace winrt::Windows::Media::MediaProperties
     struct IMediaEncodingProfileStatics;
     struct IMediaEncodingProfileStatics2;
     struct IMediaEncodingProfileStatics3;
+    struct IMediaEncodingProfileStatics4;
     struct IMediaEncodingProperties;
     struct IMediaEncodingSubtypesStatics;
     struct IMediaEncodingSubtypesStatics2;
@@ -113,6 +116,7 @@ WINRT_EXPORT namespace winrt::Windows::Media::MediaProperties
     struct IMediaEncodingSubtypesStatics4;
     struct IMediaEncodingSubtypesStatics5;
     struct IMediaEncodingSubtypesStatics6;
+    struct IMediaEncodingSubtypesStatics7;
     struct IMediaRatio;
     struct IMpeg2ProfileIdsStatics;
     struct ITimedMetadataEncodingProperties;
@@ -124,9 +128,13 @@ WINRT_EXPORT namespace winrt::Windows::Media::MediaProperties
     struct IVideoEncodingProperties5;
     struct IVideoEncodingPropertiesStatics;
     struct IVideoEncodingPropertiesStatics2;
+    struct IVideoEncodingPropertiesStatics3;
+    struct IVp9ProfileIdsStatics;
     struct AudioEncodingProperties;
+    struct Av1ProfileIds;
     struct ContainerEncodingProperties;
     struct H264ProfileIds;
+    struct HevcProfileIds;
     struct ImageEncodingProperties;
     struct MediaEncodingProfile;
     struct MediaEncodingSubtypes;
@@ -135,6 +143,7 @@ WINRT_EXPORT namespace winrt::Windows::Media::MediaProperties
     struct Mpeg2ProfileIds;
     struct TimedMetadataEncodingProperties;
     struct VideoEncodingProperties;
+    struct Vp9ProfileIds;
 }
 namespace winrt::impl
 {
@@ -144,9 +153,11 @@ namespace winrt::impl
     template <> struct category<winrt::Windows::Media::MediaProperties::IAudioEncodingPropertiesStatics>{ using type = interface_category; };
     template <> struct category<winrt::Windows::Media::MediaProperties::IAudioEncodingPropertiesStatics2>{ using type = interface_category; };
     template <> struct category<winrt::Windows::Media::MediaProperties::IAudioEncodingPropertiesWithFormatUserData>{ using type = interface_category; };
+    template <> struct category<winrt::Windows::Media::MediaProperties::IAv1ProfileIdsStatics>{ using type = interface_category; };
     template <> struct category<winrt::Windows::Media::MediaProperties::IContainerEncodingProperties>{ using type = interface_category; };
     template <> struct category<winrt::Windows::Media::MediaProperties::IContainerEncodingProperties2>{ using type = interface_category; };
     template <> struct category<winrt::Windows::Media::MediaProperties::IH264ProfileIdsStatics>{ using type = interface_category; };
+    template <> struct category<winrt::Windows::Media::MediaProperties::IHevcProfileIdsStatics>{ using type = interface_category; };
     template <> struct category<winrt::Windows::Media::MediaProperties::IImageEncodingProperties>{ using type = interface_category; };
     template <> struct category<winrt::Windows::Media::MediaProperties::IImageEncodingProperties2>{ using type = interface_category; };
     template <> struct category<winrt::Windows::Media::MediaProperties::IImageEncodingPropertiesStatics>{ using type = interface_category; };
@@ -158,6 +169,7 @@ namespace winrt::impl
     template <> struct category<winrt::Windows::Media::MediaProperties::IMediaEncodingProfileStatics>{ using type = interface_category; };
     template <> struct category<winrt::Windows::Media::MediaProperties::IMediaEncodingProfileStatics2>{ using type = interface_category; };
     template <> struct category<winrt::Windows::Media::MediaProperties::IMediaEncodingProfileStatics3>{ using type = interface_category; };
+    template <> struct category<winrt::Windows::Media::MediaProperties::IMediaEncodingProfileStatics4>{ using type = interface_category; };
     template <> struct category<winrt::Windows::Media::MediaProperties::IMediaEncodingProperties>{ using type = interface_category; };
     template <> struct category<winrt::Windows::Media::MediaProperties::IMediaEncodingSubtypesStatics>{ using type = interface_category; };
     template <> struct category<winrt::Windows::Media::MediaProperties::IMediaEncodingSubtypesStatics2>{ using type = interface_category; };
@@ -165,6 +177,7 @@ namespace winrt::impl
     template <> struct category<winrt::Windows::Media::MediaProperties::IMediaEncodingSubtypesStatics4>{ using type = interface_category; };
     template <> struct category<winrt::Windows::Media::MediaProperties::IMediaEncodingSubtypesStatics5>{ using type = interface_category; };
     template <> struct category<winrt::Windows::Media::MediaProperties::IMediaEncodingSubtypesStatics6>{ using type = interface_category; };
+    template <> struct category<winrt::Windows::Media::MediaProperties::IMediaEncodingSubtypesStatics7>{ using type = interface_category; };
     template <> struct category<winrt::Windows::Media::MediaProperties::IMediaRatio>{ using type = interface_category; };
     template <> struct category<winrt::Windows::Media::MediaProperties::IMpeg2ProfileIdsStatics>{ using type = interface_category; };
     template <> struct category<winrt::Windows::Media::MediaProperties::ITimedMetadataEncodingProperties>{ using type = interface_category; };
@@ -176,9 +189,13 @@ namespace winrt::impl
     template <> struct category<winrt::Windows::Media::MediaProperties::IVideoEncodingProperties5>{ using type = interface_category; };
     template <> struct category<winrt::Windows::Media::MediaProperties::IVideoEncodingPropertiesStatics>{ using type = interface_category; };
     template <> struct category<winrt::Windows::Media::MediaProperties::IVideoEncodingPropertiesStatics2>{ using type = interface_category; };
+    template <> struct category<winrt::Windows::Media::MediaProperties::IVideoEncodingPropertiesStatics3>{ using type = interface_category; };
+    template <> struct category<winrt::Windows::Media::MediaProperties::IVp9ProfileIdsStatics>{ using type = interface_category; };
     template <> struct category<winrt::Windows::Media::MediaProperties::AudioEncodingProperties>{ using type = class_category; };
+    template <> struct category<winrt::Windows::Media::MediaProperties::Av1ProfileIds>{ using type = class_category; };
     template <> struct category<winrt::Windows::Media::MediaProperties::ContainerEncodingProperties>{ using type = class_category; };
     template <> struct category<winrt::Windows::Media::MediaProperties::H264ProfileIds>{ using type = class_category; };
+    template <> struct category<winrt::Windows::Media::MediaProperties::HevcProfileIds>{ using type = class_category; };
     template <> struct category<winrt::Windows::Media::MediaProperties::ImageEncodingProperties>{ using type = class_category; };
     template <> struct category<winrt::Windows::Media::MediaProperties::MediaEncodingProfile>{ using type = class_category; };
     template <> struct category<winrt::Windows::Media::MediaProperties::MediaEncodingSubtypes>{ using type = class_category; };
@@ -187,6 +204,7 @@ namespace winrt::impl
     template <> struct category<winrt::Windows::Media::MediaProperties::Mpeg2ProfileIds>{ using type = class_category; };
     template <> struct category<winrt::Windows::Media::MediaProperties::TimedMetadataEncodingProperties>{ using type = class_category; };
     template <> struct category<winrt::Windows::Media::MediaProperties::VideoEncodingProperties>{ using type = class_category; };
+    template <> struct category<winrt::Windows::Media::MediaProperties::Vp9ProfileIds>{ using type = class_category; };
     template <> struct category<winrt::Windows::Media::MediaProperties::AudioEncodingQuality>{ using type = enum_category; };
     template <> struct category<winrt::Windows::Media::MediaProperties::MediaMirroringOptions>{ using type = enum_category; };
     template <> struct category<winrt::Windows::Media::MediaProperties::MediaPixelFormat>{ using type = enum_category; };
@@ -196,8 +214,10 @@ namespace winrt::impl
     template <> struct category<winrt::Windows::Media::MediaProperties::StereoscopicVideoPackingMode>{ using type = enum_category; };
     template <> struct category<winrt::Windows::Media::MediaProperties::VideoEncodingQuality>{ using type = enum_category; };
     template <> inline constexpr auto& name_v<winrt::Windows::Media::MediaProperties::AudioEncodingProperties> = L"Windows.Media.MediaProperties.AudioEncodingProperties";
+    template <> inline constexpr auto& name_v<winrt::Windows::Media::MediaProperties::Av1ProfileIds> = L"Windows.Media.MediaProperties.Av1ProfileIds";
     template <> inline constexpr auto& name_v<winrt::Windows::Media::MediaProperties::ContainerEncodingProperties> = L"Windows.Media.MediaProperties.ContainerEncodingProperties";
     template <> inline constexpr auto& name_v<winrt::Windows::Media::MediaProperties::H264ProfileIds> = L"Windows.Media.MediaProperties.H264ProfileIds";
+    template <> inline constexpr auto& name_v<winrt::Windows::Media::MediaProperties::HevcProfileIds> = L"Windows.Media.MediaProperties.HevcProfileIds";
     template <> inline constexpr auto& name_v<winrt::Windows::Media::MediaProperties::ImageEncodingProperties> = L"Windows.Media.MediaProperties.ImageEncodingProperties";
     template <> inline constexpr auto& name_v<winrt::Windows::Media::MediaProperties::MediaEncodingProfile> = L"Windows.Media.MediaProperties.MediaEncodingProfile";
     template <> inline constexpr auto& name_v<winrt::Windows::Media::MediaProperties::MediaEncodingSubtypes> = L"Windows.Media.MediaProperties.MediaEncodingSubtypes";
@@ -206,6 +226,7 @@ namespace winrt::impl
     template <> inline constexpr auto& name_v<winrt::Windows::Media::MediaProperties::Mpeg2ProfileIds> = L"Windows.Media.MediaProperties.Mpeg2ProfileIds";
     template <> inline constexpr auto& name_v<winrt::Windows::Media::MediaProperties::TimedMetadataEncodingProperties> = L"Windows.Media.MediaProperties.TimedMetadataEncodingProperties";
     template <> inline constexpr auto& name_v<winrt::Windows::Media::MediaProperties::VideoEncodingProperties> = L"Windows.Media.MediaProperties.VideoEncodingProperties";
+    template <> inline constexpr auto& name_v<winrt::Windows::Media::MediaProperties::Vp9ProfileIds> = L"Windows.Media.MediaProperties.Vp9ProfileIds";
     template <> inline constexpr auto& name_v<winrt::Windows::Media::MediaProperties::AudioEncodingQuality> = L"Windows.Media.MediaProperties.AudioEncodingQuality";
     template <> inline constexpr auto& name_v<winrt::Windows::Media::MediaProperties::MediaMirroringOptions> = L"Windows.Media.MediaProperties.MediaMirroringOptions";
     template <> inline constexpr auto& name_v<winrt::Windows::Media::MediaProperties::MediaPixelFormat> = L"Windows.Media.MediaProperties.MediaPixelFormat";
@@ -220,9 +241,11 @@ namespace winrt::impl
     template <> inline constexpr auto& name_v<winrt::Windows::Media::MediaProperties::IAudioEncodingPropertiesStatics> = L"Windows.Media.MediaProperties.IAudioEncodingPropertiesStatics";
     template <> inline constexpr auto& name_v<winrt::Windows::Media::MediaProperties::IAudioEncodingPropertiesStatics2> = L"Windows.Media.MediaProperties.IAudioEncodingPropertiesStatics2";
     template <> inline constexpr auto& name_v<winrt::Windows::Media::MediaProperties::IAudioEncodingPropertiesWithFormatUserData> = L"Windows.Media.MediaProperties.IAudioEncodingPropertiesWithFormatUserData";
+    template <> inline constexpr auto& name_v<winrt::Windows::Media::MediaProperties::IAv1ProfileIdsStatics> = L"Windows.Media.MediaProperties.IAv1ProfileIdsStatics";
     template <> inline constexpr auto& name_v<winrt::Windows::Media::MediaProperties::IContainerEncodingProperties> = L"Windows.Media.MediaProperties.IContainerEncodingProperties";
     template <> inline constexpr auto& name_v<winrt::Windows::Media::MediaProperties::IContainerEncodingProperties2> = L"Windows.Media.MediaProperties.IContainerEncodingProperties2";
     template <> inline constexpr auto& name_v<winrt::Windows::Media::MediaProperties::IH264ProfileIdsStatics> = L"Windows.Media.MediaProperties.IH264ProfileIdsStatics";
+    template <> inline constexpr auto& name_v<winrt::Windows::Media::MediaProperties::IHevcProfileIdsStatics> = L"Windows.Media.MediaProperties.IHevcProfileIdsStatics";
     template <> inline constexpr auto& name_v<winrt::Windows::Media::MediaProperties::IImageEncodingProperties> = L"Windows.Media.MediaProperties.IImageEncodingProperties";
     template <> inline constexpr auto& name_v<winrt::Windows::Media::MediaProperties::IImageEncodingProperties2> = L"Windows.Media.MediaProperties.IImageEncodingProperties2";
     template <> inline constexpr auto& name_v<winrt::Windows::Media::MediaProperties::IImageEncodingPropertiesStatics> = L"Windows.Media.MediaProperties.IImageEncodingPropertiesStatics";
@@ -234,6 +257,7 @@ namespace winrt::impl
     template <> inline constexpr auto& name_v<winrt::Windows::Media::MediaProperties::IMediaEncodingProfileStatics> = L"Windows.Media.MediaProperties.IMediaEncodingProfileStatics";
     template <> inline constexpr auto& name_v<winrt::Windows::Media::MediaProperties::IMediaEncodingProfileStatics2> = L"Windows.Media.MediaProperties.IMediaEncodingProfileStatics2";
     template <> inline constexpr auto& name_v<winrt::Windows::Media::MediaProperties::IMediaEncodingProfileStatics3> = L"Windows.Media.MediaProperties.IMediaEncodingProfileStatics3";
+    template <> inline constexpr auto& name_v<winrt::Windows::Media::MediaProperties::IMediaEncodingProfileStatics4> = L"Windows.Media.MediaProperties.IMediaEncodingProfileStatics4";
     template <> inline constexpr auto& name_v<winrt::Windows::Media::MediaProperties::IMediaEncodingProperties> = L"Windows.Media.MediaProperties.IMediaEncodingProperties";
     template <> inline constexpr auto& name_v<winrt::Windows::Media::MediaProperties::IMediaEncodingSubtypesStatics> = L"Windows.Media.MediaProperties.IMediaEncodingSubtypesStatics";
     template <> inline constexpr auto& name_v<winrt::Windows::Media::MediaProperties::IMediaEncodingSubtypesStatics2> = L"Windows.Media.MediaProperties.IMediaEncodingSubtypesStatics2";
@@ -241,6 +265,7 @@ namespace winrt::impl
     template <> inline constexpr auto& name_v<winrt::Windows::Media::MediaProperties::IMediaEncodingSubtypesStatics4> = L"Windows.Media.MediaProperties.IMediaEncodingSubtypesStatics4";
     template <> inline constexpr auto& name_v<winrt::Windows::Media::MediaProperties::IMediaEncodingSubtypesStatics5> = L"Windows.Media.MediaProperties.IMediaEncodingSubtypesStatics5";
     template <> inline constexpr auto& name_v<winrt::Windows::Media::MediaProperties::IMediaEncodingSubtypesStatics6> = L"Windows.Media.MediaProperties.IMediaEncodingSubtypesStatics6";
+    template <> inline constexpr auto& name_v<winrt::Windows::Media::MediaProperties::IMediaEncodingSubtypesStatics7> = L"Windows.Media.MediaProperties.IMediaEncodingSubtypesStatics7";
     template <> inline constexpr auto& name_v<winrt::Windows::Media::MediaProperties::IMediaRatio> = L"Windows.Media.MediaProperties.IMediaRatio";
     template <> inline constexpr auto& name_v<winrt::Windows::Media::MediaProperties::IMpeg2ProfileIdsStatics> = L"Windows.Media.MediaProperties.IMpeg2ProfileIdsStatics";
     template <> inline constexpr auto& name_v<winrt::Windows::Media::MediaProperties::ITimedMetadataEncodingProperties> = L"Windows.Media.MediaProperties.ITimedMetadataEncodingProperties";
@@ -252,15 +277,19 @@ namespace winrt::impl
     template <> inline constexpr auto& name_v<winrt::Windows::Media::MediaProperties::IVideoEncodingProperties5> = L"Windows.Media.MediaProperties.IVideoEncodingProperties5";
     template <> inline constexpr auto& name_v<winrt::Windows::Media::MediaProperties::IVideoEncodingPropertiesStatics> = L"Windows.Media.MediaProperties.IVideoEncodingPropertiesStatics";
     template <> inline constexpr auto& name_v<winrt::Windows::Media::MediaProperties::IVideoEncodingPropertiesStatics2> = L"Windows.Media.MediaProperties.IVideoEncodingPropertiesStatics2";
+    template <> inline constexpr auto& name_v<winrt::Windows::Media::MediaProperties::IVideoEncodingPropertiesStatics3> = L"Windows.Media.MediaProperties.IVideoEncodingPropertiesStatics3";
+    template <> inline constexpr auto& name_v<winrt::Windows::Media::MediaProperties::IVp9ProfileIdsStatics> = L"Windows.Media.MediaProperties.IVp9ProfileIdsStatics";
     template <> inline constexpr guid guid_v<winrt::Windows::Media::MediaProperties::IAudioEncodingProperties>{ 0x62BC7A16,0x005C,0x4B3B,{ 0x8A,0x0B,0x0A,0x09,0x0E,0x96,0x87,0xF3 } }; // 62BC7A16-005C-4B3B-8A0B-0A090E9687F3
     template <> inline constexpr guid guid_v<winrt::Windows::Media::MediaProperties::IAudioEncodingProperties2>{ 0xC45D54DA,0x80BD,0x4C23,{ 0x80,0xD5,0x72,0xD4,0xA1,0x81,0xE8,0x94 } }; // C45D54DA-80BD-4C23-80D5-72D4A181E894
     template <> inline constexpr guid guid_v<winrt::Windows::Media::MediaProperties::IAudioEncodingProperties3>{ 0x87600341,0x748C,0x4F8D,{ 0xB0,0xFD,0x10,0xCA,0xF0,0x8F,0xF0,0x87 } }; // 87600341-748C-4F8D-B0FD-10CAF08FF087
     template <> inline constexpr guid guid_v<winrt::Windows::Media::MediaProperties::IAudioEncodingPropertiesStatics>{ 0x0CAD332C,0xEBE9,0x4527,{ 0xB3,0x6D,0xE4,0x2A,0x13,0xCF,0x38,0xDB } }; // 0CAD332C-EBE9-4527-B36D-E42A13CF38DB
     template <> inline constexpr guid guid_v<winrt::Windows::Media::MediaProperties::IAudioEncodingPropertiesStatics2>{ 0x7489316F,0x77A0,0x433D,{ 0x8E,0xD5,0x40,0x40,0x28,0x0E,0x86,0x65 } }; // 7489316F-77A0-433D-8ED5-4040280E8665
     template <> inline constexpr guid guid_v<winrt::Windows::Media::MediaProperties::IAudioEncodingPropertiesWithFormatUserData>{ 0x98F10D79,0x13EA,0x49FF,{ 0xBE,0x70,0x26,0x73,0xDB,0x69,0x70,0x2C } }; // 98F10D79-13EA-49FF-BE70-2673DB69702C
+    template <> inline constexpr guid guid_v<winrt::Windows::Media::MediaProperties::IAv1ProfileIdsStatics>{ 0x9105812B,0x7C09,0x5882,{ 0x88,0xA4,0x67,0x80,0x08,0xA5,0x17,0x4D } }; // 9105812B-7C09-5882-88A4-678008A5174D
     template <> inline constexpr guid guid_v<winrt::Windows::Media::MediaProperties::IContainerEncodingProperties>{ 0x59AC2A57,0xB32A,0x479E,{ 0x8A,0x61,0x4B,0x7F,0x2E,0x9E,0x7E,0xA0 } }; // 59AC2A57-B32A-479E-8A61-4B7F2E9E7EA0
     template <> inline constexpr guid guid_v<winrt::Windows::Media::MediaProperties::IContainerEncodingProperties2>{ 0xB272C029,0xAE26,0x4819,{ 0xBA,0xAD,0xAD,0x7A,0x49,0xB0,0xA8,0x76 } }; // B272C029-AE26-4819-BAAD-AD7A49B0A876
     template <> inline constexpr guid guid_v<winrt::Windows::Media::MediaProperties::IH264ProfileIdsStatics>{ 0x38654CA7,0x846A,0x4F97,{ 0xA2,0xE5,0xC3,0xA1,0x5B,0xBF,0x70,0xFD } }; // 38654CA7-846A-4F97-A2E5-C3A15BBF70FD
+    template <> inline constexpr guid guid_v<winrt::Windows::Media::MediaProperties::IHevcProfileIdsStatics>{ 0x1E50D280,0x2AA7,0x53C1,{ 0x97,0x3F,0x21,0x89,0xFA,0x65,0x6F,0x53 } }; // 1E50D280-2AA7-53C1-973F-2189FA656F53
     template <> inline constexpr guid guid_v<winrt::Windows::Media::MediaProperties::IImageEncodingProperties>{ 0x78625635,0xF331,0x4189,{ 0xB1,0xC3,0xB4,0x8D,0x5A,0xE0,0x34,0xF1 } }; // 78625635-F331-4189-B1C3-B48D5AE034F1
     template <> inline constexpr guid guid_v<winrt::Windows::Media::MediaProperties::IImageEncodingProperties2>{ 0xC854A2DF,0xC923,0x469B,{ 0xAC,0x8E,0x6A,0x9F,0x3C,0x1C,0xD9,0xE3 } }; // C854A2DF-C923-469B-AC8E-6A9F3C1CD9E3
     template <> inline constexpr guid guid_v<winrt::Windows::Media::MediaProperties::IImageEncodingPropertiesStatics>{ 0x257C68DC,0x8B99,0x439E,{ 0xAA,0x59,0x91,0x3A,0x36,0x16,0x12,0x97 } }; // 257C68DC-8B99-439E-AA59-913A36161297
@@ -272,6 +301,7 @@ namespace winrt::impl
     template <> inline constexpr guid guid_v<winrt::Windows::Media::MediaProperties::IMediaEncodingProfileStatics>{ 0x197F352C,0x2EDE,0x4A45,{ 0xA8,0x96,0x81,0x7A,0x48,0x54,0xF8,0xFE } }; // 197F352C-2EDE-4A45-A896-817A4854F8FE
     template <> inline constexpr guid guid_v<winrt::Windows::Media::MediaProperties::IMediaEncodingProfileStatics2>{ 0xCE8DE74F,0x6AF4,0x4288,{ 0x8F,0xE2,0x79,0xAD,0xF1,0xF7,0x9A,0x43 } }; // CE8DE74F-6AF4-4288-8FE2-79ADF1F79A43
     template <> inline constexpr guid guid_v<winrt::Windows::Media::MediaProperties::IMediaEncodingProfileStatics3>{ 0x90DAC5AA,0xCF76,0x4294,{ 0xA9,0xED,0x1A,0x14,0x20,0xF5,0x1F,0x6B } }; // 90DAC5AA-CF76-4294-A9ED-1A1420F51F6B
+    template <> inline constexpr guid guid_v<winrt::Windows::Media::MediaProperties::IMediaEncodingProfileStatics4>{ 0x6FAFD7B5,0x9404,0x514A,{ 0x81,0xDD,0xC9,0x44,0x4D,0x64,0x8A,0xF0 } }; // 6FAFD7B5-9404-514A-81DD-C9444D648AF0
     template <> inline constexpr guid guid_v<winrt::Windows::Media::MediaProperties::IMediaEncodingProperties>{ 0xB4002AF6,0xACD4,0x4E5A,{ 0xA2,0x4B,0x5D,0x74,0x98,0xA8,0xB8,0xC4 } }; // B4002AF6-ACD4-4E5A-A24B-5D7498A8B8C4
     template <> inline constexpr guid guid_v<winrt::Windows::Media::MediaProperties::IMediaEncodingSubtypesStatics>{ 0x37B6580E,0xA171,0x4464,{ 0xBA,0x5A,0x53,0x18,0x9E,0x48,0xC1,0xC8 } }; // 37B6580E-A171-4464-BA5A-53189E48C1C8
     template <> inline constexpr guid guid_v<winrt::Windows::Media::MediaProperties::IMediaEncodingSubtypesStatics2>{ 0x4B7CD23D,0x42FF,0x4D33,{ 0x85,0x31,0x06,0x26,0xBE,0xE4,0xB5,0x2D } }; // 4B7CD23D-42FF-4D33-8531-0626BEE4B52D
@@ -279,6 +309,7 @@ namespace winrt::impl
     template <> inline constexpr guid guid_v<winrt::Windows::Media::MediaProperties::IMediaEncodingSubtypesStatics4>{ 0xDDECE58A,0x3949,0x4644,{ 0x8A,0x2C,0x59,0xEF,0x02,0xC6,0x42,0xFA } }; // DDECE58A-3949-4644-8A2C-59EF02C642FA
     template <> inline constexpr guid guid_v<winrt::Windows::Media::MediaProperties::IMediaEncodingSubtypesStatics5>{ 0x5AD4A007,0xFFCE,0x4760,{ 0x98,0x28,0x5D,0x0C,0x99,0x63,0x7E,0x6A } }; // 5AD4A007-FFCE-4760-9828-5D0C99637E6A
     template <> inline constexpr guid guid_v<winrt::Windows::Media::MediaProperties::IMediaEncodingSubtypesStatics6>{ 0xA1252973,0xA984,0x5912,{ 0x93,0xBB,0x54,0xE7,0xE5,0x69,0xE0,0x53 } }; // A1252973-A984-5912-93BB-54E7E569E053
+    template <> inline constexpr guid guid_v<winrt::Windows::Media::MediaProperties::IMediaEncodingSubtypesStatics7>{ 0x92F2DCA7,0x9937,0x52A1,{ 0xB6,0x19,0xDD,0xFA,0xD8,0x1C,0xD9,0x9C } }; // 92F2DCA7-9937-52A1-B619-DDFAD81CD99C
     template <> inline constexpr guid guid_v<winrt::Windows::Media::MediaProperties::IMediaRatio>{ 0xD2D0FEE5,0x8929,0x401D,{ 0xAC,0x78,0x7D,0x35,0x7E,0x37,0x81,0x63 } }; // D2D0FEE5-8929-401D-AC78-7D357E378163
     template <> inline constexpr guid guid_v<winrt::Windows::Media::MediaProperties::IMpeg2ProfileIdsStatics>{ 0xA461FF85,0xE57A,0x4128,{ 0x9B,0x21,0xD5,0x33,0x1B,0x04,0x23,0x5C } }; // A461FF85-E57A-4128-9B21-D5331B04235C
     template <> inline constexpr guid guid_v<winrt::Windows::Media::MediaProperties::ITimedMetadataEncodingProperties>{ 0x51CD30D3,0xD690,0x4CFA,{ 0x97,0xF4,0x4A,0x39,0x8E,0x9D,0xB4,0x20 } }; // 51CD30D3-D690-4CFA-97F4-4A398E9DB420
@@ -290,6 +321,8 @@ namespace winrt::impl
     template <> inline constexpr guid guid_v<winrt::Windows::Media::MediaProperties::IVideoEncodingProperties5>{ 0x4959080F,0x272F,0x4ECE,{ 0xA4,0xDF,0xC0,0xCC,0xDB,0x33,0xD8,0x40 } }; // 4959080F-272F-4ECE-A4DF-C0CCDB33D840
     template <> inline constexpr guid guid_v<winrt::Windows::Media::MediaProperties::IVideoEncodingPropertiesStatics>{ 0x3CE14D44,0x1DC5,0x43DB,{ 0x9F,0x38,0xEB,0xEB,0xF9,0x01,0x52,0xCB } }; // 3CE14D44-1DC5-43DB-9F38-EBEBF90152CB
     template <> inline constexpr guid guid_v<winrt::Windows::Media::MediaProperties::IVideoEncodingPropertiesStatics2>{ 0xCF1EBD5D,0x49FE,0x4D00,{ 0xB5,0x9A,0xCF,0xA4,0xDF,0xC5,0x19,0x44 } }; // CF1EBD5D-49FE-4D00-B59A-CFA4DFC51944
+    template <> inline constexpr guid guid_v<winrt::Windows::Media::MediaProperties::IVideoEncodingPropertiesStatics3>{ 0x65B46685,0x60DA,0x5E51,{ 0x91,0xA2,0xB3,0x8C,0x47,0x63,0xB8,0x72 } }; // 65B46685-60DA-5E51-91A2-B38C4763B872
+    template <> inline constexpr guid guid_v<winrt::Windows::Media::MediaProperties::IVp9ProfileIdsStatics>{ 0x20311A55,0xFE06,0x5883,{ 0x92,0xD9,0x60,0x80,0xC9,0x77,0x43,0xE5 } }; // 20311A55-FE06-5883-92D9-6080C97743E5
     template <> struct default_interface<winrt::Windows::Media::MediaProperties::AudioEncodingProperties>{ using type = winrt::Windows::Media::MediaProperties::IAudioEncodingProperties; };
     template <> struct default_interface<winrt::Windows::Media::MediaProperties::ContainerEncodingProperties>{ using type = winrt::Windows::Media::MediaProperties::IContainerEncodingProperties; };
     template <> struct default_interface<winrt::Windows::Media::MediaProperties::ImageEncodingProperties>{ using type = winrt::Windows::Media::MediaProperties::IImageEncodingProperties; };
@@ -353,6 +386,24 @@ namespace winrt::impl
             virtual int32_t __stdcall GetFormatUserData(uint32_t*, uint8_t**) noexcept = 0;
         };
     };
+    template <> struct abi<winrt::Windows::Media::MediaProperties::IAv1ProfileIdsStatics>
+    {
+        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
+        {
+            virtual int32_t __stdcall get_MainChromaSubsampling420BitDepth8(int32_t*) noexcept = 0;
+            virtual int32_t __stdcall get_MainChromaSubsampling420BitDepth10(int32_t*) noexcept = 0;
+            virtual int32_t __stdcall get_MainChromaSubsampling400BitDepth8(int32_t*) noexcept = 0;
+            virtual int32_t __stdcall get_MainChromaSubsampling400BitDepth10(int32_t*) noexcept = 0;
+            virtual int32_t __stdcall get_HighChromaSubsampling444BitDepth8(int32_t*) noexcept = 0;
+            virtual int32_t __stdcall get_HighChromaSubsampling444BitDepth10(int32_t*) noexcept = 0;
+            virtual int32_t __stdcall get_ProfessionalChromaSubsampling420BitDepth12(int32_t*) noexcept = 0;
+            virtual int32_t __stdcall get_ProfessionalChromaSubsampling400BitDepth12(int32_t*) noexcept = 0;
+            virtual int32_t __stdcall get_ProfessionalChromaSubsampling444BitDepth12(int32_t*) noexcept = 0;
+            virtual int32_t __stdcall get_ProfessionalChromaSubsampling422BitDepth8(int32_t*) noexcept = 0;
+            virtual int32_t __stdcall get_ProfessionalChromaSubsampling422BitDepth10(int32_t*) noexcept = 0;
+            virtual int32_t __stdcall get_ProfessionalChromaSubsampling422BitDepth12(int32_t*) noexcept = 0;
+        };
+    };
     template <> struct abi<winrt::Windows::Media::MediaProperties::IContainerEncodingProperties>
     {
         struct WINRT_IMPL_NOVTABLE type : inspectable_abi
@@ -382,6 +433,34 @@ namespace winrt::impl
             virtual int32_t __stdcall get_MultiviewHigh(int32_t*) noexcept = 0;
         };
     };
+    template <> struct abi<winrt::Windows::Media::MediaProperties::IHevcProfileIdsStatics>
+    {
+        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
+        {
+            virtual int32_t __stdcall get_MainChromaSubsampling420BitDepth8(int32_t*) noexcept = 0;
+            virtual int32_t __stdcall get_MainChromaSubsampling420BitDepth10(int32_t*) noexcept = 0;
+            virtual int32_t __stdcall get_MainChromaSubsampling420BitDepth12(int32_t*) noexcept = 0;
+            virtual int32_t __stdcall get_MainChromaSubsampling422BitDepth10(int32_t*) noexcept = 0;
+            virtual int32_t __stdcall get_MainChromaSubsampling422BitDepth12(int32_t*) noexcept = 0;
+            virtual int32_t __stdcall get_MainChromaSubsampling444BitDepth8(int32_t*) noexcept = 0;
+            virtual int32_t __stdcall get_MainChromaSubsampling444BitDepth10(int32_t*) noexcept = 0;
+            virtual int32_t __stdcall get_MainChromaSubsampling444BitDepth12(int32_t*) noexcept = 0;
+            virtual int32_t __stdcall get_MonochromeBitDepth12(int32_t*) noexcept = 0;
+            virtual int32_t __stdcall get_MonochromeBitDepth16(int32_t*) noexcept = 0;
+            virtual int32_t __stdcall get_MainIntraChromaSubsampling420BitDepth8(int32_t*) noexcept = 0;
+            virtual int32_t __stdcall get_MainIntraChromaSubsampling420BitDepth10(int32_t*) noexcept = 0;
+            virtual int32_t __stdcall get_MainIntraChromaSubsampling420BitDepth12(int32_t*) noexcept = 0;
+            virtual int32_t __stdcall get_MainIntraChromaSubsampling422BitDepth10(int32_t*) noexcept = 0;
+            virtual int32_t __stdcall get_MainIntraChromaSubsampling422BitDepth12(int32_t*) noexcept = 0;
+            virtual int32_t __stdcall get_MainIntraChromaSubsampling444BitDepth8(int32_t*) noexcept = 0;
+            virtual int32_t __stdcall get_MainIntraChromaSubsampling444BitDepth10(int32_t*) noexcept = 0;
+            virtual int32_t __stdcall get_MainIntraChromaSubsampling444BitDepth12(int32_t*) noexcept = 0;
+            virtual int32_t __stdcall get_MainIntraChromaSubsampling444BitDepth16(int32_t*) noexcept = 0;
+            virtual int32_t __stdcall get_MainStillChromaSubsampling420BitDepth8(int32_t*) noexcept = 0;
+            virtual int32_t __stdcall get_MainStillChromaSubsampling444BitDepth8(int32_t*) noexcept = 0;
+            virtual int32_t __stdcall get_MainStillChromaSubsampling444BitDepth16(int32_t*) noexcept = 0;
+        };
+    };
     template <> struct abi<winrt::Windows::Media::MediaProperties::IImageEncodingProperties>
     {
         struct WINRT_IMPL_NOVTABLE type : inspectable_abi
@@ -483,6 +562,14 @@ namespace winrt::impl
             virtual int32_t __stdcall CreateHevc(int32_t, void**) noexcept = 0;
         };
     };
+    template <> struct abi<winrt::Windows::Media::MediaProperties::IMediaEncodingProfileStatics4>
+    {
+        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
+        {
+            virtual int32_t __stdcall CreateVp9(int32_t, void**) noexcept = 0;
+            virtual int32_t __stdcall CreateAv1(int32_t, void**) noexcept = 0;
+        };
+    };
     template <> struct abi<winrt::Windows::Media::MediaProperties::IMediaEncodingProperties>
     {
         struct WINRT_IMPL_NOVTABLE type : inspectable_abi
@@ -581,6 +668,13 @@ namespace winrt::impl
             virtual int32_t __stdcall get_VobSub(void**) noexcept = 0;
         };
     };
+    template <> struct abi<winrt::Windows::Media::MediaProperties::IMediaEncodingSubtypesStatics7>
+    {
+        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
+        {
+            virtual int32_t __stdcall get_Av1(void**) noexcept = 0;
+        };
+    };
     template <> struct abi<winrt::Windows::Media::MediaProperties::IMediaRatio>
     {
         struct WINRT_IMPL_NOVTABLE type : inspectable_abi
@@ -682,6 +776,23 @@ namespace winrt::impl
             virtual int32_t __stdcall CreateHevc(void**) noexcept = 0;
         };
     };
+    template <> struct abi<winrt::Windows::Media::MediaProperties::IVideoEncodingPropertiesStatics3>
+    {
+        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
+        {
+            virtual int32_t __stdcall CreateVp9(void**) noexcept = 0;
+            virtual int32_t __stdcall CreateAv1(void**) noexcept = 0;
+        };
+    };
+    template <> struct abi<winrt::Windows::Media::MediaProperties::IVp9ProfileIdsStatics>
+    {
+        struct WINRT_IMPL_NOVTABLE type : inspectable_abi
+        {
+            virtual int32_t __stdcall get_Profile0ChromaSubsampling420BitDepth8(int32_t*) noexcept = 0;
+            virtual int32_t __stdcall get_Profile2ChromaSubsampling420BitDepth10(int32_t*) noexcept = 0;
+            virtual int32_t __stdcall get_Profile2ChromaSubsampling420BitDepth12(int32_t*) noexcept = 0;
+        };
+    };
     template <typename D>
     struct consume_Windows_Media_MediaProperties_IAudioEncodingProperties
     {
@@ -750,6 +861,26 @@ namespace winrt::impl
         template <typename D> using type = consume_Windows_Media_MediaProperties_IAudioEncodingPropertiesWithFormatUserData<D>;
     };
     template <typename D>
+    struct consume_Windows_Media_MediaProperties_IAv1ProfileIdsStatics
+    {
+        [[nodiscard]] auto MainChromaSubsampling420BitDepth8() const;
+        [[nodiscard]] auto MainChromaSubsampling420BitDepth10() const;
+        [[nodiscard]] auto MainChromaSubsampling400BitDepth8() const;
+        [[nodiscard]] auto MainChromaSubsampling400BitDepth10() const;
+        [[nodiscard]] auto HighChromaSubsampling444BitDepth8() const;
+        [[nodiscard]] auto HighChromaSubsampling444BitDepth10() const;
+        [[nodiscard]] auto ProfessionalChromaSubsampling420BitDepth12() const;
+        [[nodiscard]] auto ProfessionalChromaSubsampling400BitDepth12() const;
+        [[nodiscard]] auto ProfessionalChromaSubsampling444BitDepth12() const;
+        [[nodiscard]] auto ProfessionalChromaSubsampling422BitDepth8() const;
+        [[nodiscard]] auto ProfessionalChromaSubsampling422BitDepth10() const;
+        [[nodiscard]] auto ProfessionalChromaSubsampling422BitDepth12() const;
+    };
+    template <> struct consume<winrt::Windows::Media::MediaProperties::IAv1ProfileIdsStatics>
+    {
+        template <typename D> using type = consume_Windows_Media_MediaProperties_IAv1ProfileIdsStatics<D>;
+    };
+    template <typename D>
     struct consume_Windows_Media_MediaProperties_IContainerEncodingProperties
     {
     };
@@ -785,6 +916,36 @@ namespace winrt::impl
         template <typename D> using type = consume_Windows_Media_MediaProperties_IH264ProfileIdsStatics<D>;
     };
     template <typename D>
+    struct consume_Windows_Media_MediaProperties_IHevcProfileIdsStatics
+    {
+        [[nodiscard]] auto MainChromaSubsampling420BitDepth8() const;
+        [[nodiscard]] auto MainChromaSubsampling420BitDepth10() const;
+        [[nodiscard]] auto MainChromaSubsampling420BitDepth12() const;
+        [[nodiscard]] auto MainChromaSubsampling422BitDepth10() const;
+        [[nodiscard]] auto MainChromaSubsampling422BitDepth12() const;
+        [[nodiscard]] auto MainChromaSubsampling444BitDepth8() const;
+        [[nodiscard]] auto MainChromaSubsampling444BitDepth10() const;
+        [[nodiscard]] auto MainChromaSubsampling444BitDepth12() const;
+        [[nodiscard]] auto MonochromeBitDepth12() const;
+        [[nodiscard]] auto MonochromeBitDepth16() const;
+        [[nodiscard]] auto MainIntraChromaSubsampling420BitDepth8() const;
+        [[nodiscard]] auto MainIntraChromaSubsampling420BitDepth10() const;
+        [[nodiscard]] auto MainIntraChromaSubsampling420BitDepth12() const;
+        [[nodiscard]] auto MainIntraChromaSubsampling422BitDepth10() const;
+        [[nodiscard]] auto MainIntraChromaSubsampling422BitDepth12() const;
+        [[nodiscard]] auto MainIntraChromaSubsampling444BitDepth8() const;
+        [[nodiscard]] auto MainIntraChromaSubsampling444BitDepth10() const;
+        [[nodiscard]] auto MainIntraChromaSubsampling444BitDepth12() const;
+        [[nodiscard]] auto MainIntraChromaSubsampling444BitDepth16() const;
+        [[nodiscard]] auto MainStillChromaSubsampling420BitDepth8() const;
+        [[nodiscard]] auto MainStillChromaSubsampling444BitDepth8() const;
+        [[nodiscard]] auto MainStillChromaSubsampling444BitDepth16() const;
+    };
+    template <> struct consume<winrt::Windows::Media::MediaProperties::IHevcProfileIdsStatics>
+    {
+        template <typename D> using type = consume_Windows_Media_MediaProperties_IHevcProfileIdsStatics<D>;
+    };
+    template <typename D>
     struct consume_Windows_Media_MediaProperties_IImageEncodingProperties
     {
         auto Width(uint32_t value) const;
@@ -908,6 +1069,16 @@ namespace winrt::impl
         template <typename D> using type = consume_Windows_Media_MediaProperties_IMediaEncodingProfileStatics3<D>;
     };
     template <typename D>
+    struct consume_Windows_Media_MediaProperties_IMediaEncodingProfileStatics4
+    {
+        auto CreateVp9(winrt::Windows::Media::MediaProperties::VideoEncodingQuality const& quality) const;
+        auto CreateAv1(winrt::Windows::Media::MediaProperties::VideoEncodingQuality const& quality) const;
+    };
+    template <> struct consume<winrt::Windows::Media::MediaProperties::IMediaEncodingProfileStatics4>
+    {
+        template <typename D> using type = consume_Windows_Media_MediaProperties_IMediaEncodingProfileStatics4<D>;
+    };
+    template <typename D>
     struct consume_Windows_Media_MediaProperties_IMediaEncodingProperties
     {
         [[nodiscard]] auto Properties() const;
@@ -1020,6 +1191,15 @@ namespace winrt::impl
         template <typename D> using type = consume_Windows_Media_MediaProperties_IMediaEncodingSubtypesStatics6<D>;
     };
     template <typename D>
+    struct consume_Windows_Media_MediaProperties_IMediaEncodingSubtypesStatics7
+    {
+        [[nodiscard]] auto Av1() const;
+    };
+    template <> struct consume<winrt::Windows::Media::MediaProperties::IMediaEncodingSubtypesStatics7>
+    {
+        template <typename D> using type = consume_Windows_Media_MediaProperties_IMediaEncodingSubtypesStatics7<D>;
+    };
+    template <typename D>
     struct consume_Windows_Media_MediaProperties_IMediaRatio
     {
         auto Numerator(uint32_t value) const;
@@ -1142,5 +1322,26 @@ namespace winrt::impl
     {
         template <typename D> using type = consume_Windows_Media_MediaProperties_IVideoEncodingPropertiesStatics2<D>;
     };
+    template <typename D>
+    struct consume_Windows_Media_MediaProperties_IVideoEncodingPropertiesStatics3
+    {
+        auto CreateVp9() const;
+        auto CreateAv1() const;
+    };
+    template <> struct consume<winrt::Windows::Media::MediaProperties::IVideoEncodingPropertiesStatics3>
+    {
+        template <typename D> using type = consume_Windows_Media_MediaProperties_IVideoEncodingPropertiesStatics3<D>;
+    };
+    template <typename D>
+    struct consume_Windows_Media_MediaProperties_IVp9ProfileIdsStatics
+    {
+        [[nodiscard]] auto Profile0ChromaSubsampling420BitDepth8() const;
+        [[nodiscard]] auto Profile2ChromaSubsampling420BitDepth10() const;
+        [[nodiscard]] auto Profile2ChromaSubsampling420BitDepth12() const;
+    };
+    template <> struct consume<winrt::Windows::Media::MediaProperties::IVp9ProfileIdsStatics>
+    {
+        template <typename D> using type = consume_Windows_Media_MediaProperties_IVp9ProfileIdsStatics<D>;
+    };
 }
 #endif
