@@ -1,4 +1,4 @@
-// C++/WinRT v2.0.240111.5
+// C++/WinRT v2.0.250303.1
 
 // SPDX-License-Identifier: MIT OR Apache-2.0
 // SPDX-FileCopyrightText: Copyright (c) Microsoft Corporation
@@ -19,6 +19,13 @@ WINRT_EXPORT namespace winrt::Windows::System::RemoteDesktop::Input
         IRemoteTextConnection(std::nullptr_t = nullptr) noexcept {}
         IRemoteTextConnection(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
     };
+    struct WINRT_IMPL_EMPTY_BASES IRemoteTextConnection2 :
+        winrt::Windows::Foundation::IInspectable,
+        impl::consume_t<IRemoteTextConnection2>
+    {
+        IRemoteTextConnection2(std::nullptr_t = nullptr) noexcept {}
+        IRemoteTextConnection2(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
+    };
     struct WINRT_IMPL_EMPTY_BASES IRemoteTextConnectionFactory :
         winrt::Windows::Foundation::IInspectable,
         impl::consume_t<IRemoteTextConnectionFactory>
@@ -26,5 +33,12 @@ WINRT_EXPORT namespace winrt::Windows::System::RemoteDesktop::Input
         IRemoteTextConnectionFactory(std::nullptr_t = nullptr) noexcept {}
         IRemoteTextConnectionFactory(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
     };
+    struct WINRT_IMPL_EMPTY_BASES IRemoteTextConnectionFactory2 :
+        winrt::Windows::Foundation::IInspectable,
+        impl::consume_t<IRemoteTextConnectionFactory2>
+    {
+        IRemoteTextConnectionFactory2(std::nullptr_t = nullptr) noexcept {}
+        IRemoteTextConnectionFactory2(void* ptr, take_ownership_from_abi_t) noexcept : winrt::Windows::Foundation::IInspectable(ptr, take_ownership_from_abi) {}
+    };
 }
 #endif
