@@ -1,4 +1,4 @@
-// C++/WinRT v2.0.240405.15
+// C++/WinRT v2.0.250303.1
 
 // SPDX-License-Identifier: MIT OR Apache-2.0
 // SPDX-FileCopyrightText: Copyright (c) Microsoft Corporation
@@ -14,7 +14,7 @@ WINRT_EXPORT namespace winrt::Windows::UI::Text
 {
     struct FontWeight
     {
-        uint16_t Weight;
+        uint16_t Weight {};
     };
     inline bool operator==(FontWeight const& left, FontWeight const& right) noexcept
     {
