@@ -1,4 +1,4 @@
-// C++/WinRT v2.0.240405.15
+// C++/WinRT v2.0.250303.1
 
 // SPDX-License-Identifier: MIT OR Apache-2.0
 // SPDX-FileCopyrightText: Copyright (c) Microsoft Corporation
@@ -41,7 +41,7 @@ WINRT_EXPORT namespace winrt::Windows::UI::Xaml::Data
     };
     struct LoadMoreItemsResult
     {
-        uint32_t Count;
+        uint32_t Count {};
     };
     inline bool operator==(LoadMoreItemsResult const& left, LoadMoreItemsResult const& right) noexcept
     {
